#
# spec file for package darktable
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?fedora_version}
%bcond_with    basecurve_tool
%else
%bcond_without basecurve_tool
%endif
%bcond_with clang

%if 0%{?is_opensuse} || 0%{?fedora_version} >= 26
%bcond_without osmgpsmap
%bcond_without flickcurl
%bcond_without translated_manpages
%else
%bcond_with    osmgpsmap
%bcond_with    flickcurl
%bcond_with    translated_manpages
%endif

%if 0%{?suse_version} >= 1330 || 0%{?fedora_version} >= 26
%bcond_without  system_lua
%else
%bcond_with     system_lua
%endif

%if 0%{?suse_version} > 1320 || 0%{?fedora_version} >= 26
%bcond_without  system_opencl
%else
%bcond_with     system_opencl
%endif

%global _libexec_subdir "lib"
%if 0%{?fedora_version}
%global _libexec_subdir "libexec"
%endif

%define cmake_options -DCMAKE_SKIP_RPATH:BOOL=OFF -DCMAKE_BUILD_TYPE=Release -DBINARY_PACKAGE_BUILD=1 -DCMAKE_INSTALL_DATAROOTDIR="share" -DCMAKE_INSTALL_LIBDIR="%{_lib}" -DCMAKE_INSTALL_LIBEXECDIR="%{_libexec_subdir}" -DBUILD_NOISE_TOOLS=ON

%if 0%{?suse_version} == 1315
%define force_gcc_version 7
%endif

Name:           darktable
Version:        2.4.3
Release:        lp150.2.1
%define pkg_name darktable
%define pkg_version 2.4.3
Url:            http://www.darktable.org/
Source0:        %{name}-%{pkg_version}.tar.xz
Source1:        https://github.com/darktable-org/darktable/releases/download/release-2.0.0/darktable-usermanual.pdf
Source2:        https://github.com/darktable-org/darktable/releases/download/release-2.0.0/darktable-usermanual-fr.pdf
Source3:        https://github.com/darktable-org/darktable/releases/download/release-2.0.0/darktable-usermanual-es.pdf
Source4:        https://github.com/darktable-org/darktable/releases/download/release-2.0.0/darktable-lua-api.pdf
Source97:       darktable.dsc
Source98:       debian.tar.xz
Source99:       README.openSUSE
Patch:          darktable-old-glib.patch
Patch1:         887d55c.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

ExclusiveArch:  x86_64 aarch64
# build time tools
BuildRequires:  clang
BuildRequires:  cmake >= 3
BuildRequires:  fdupes
BuildRequires:  llvm-devel
%if 0%{?fedora_version}
BuildRequires:  llvm-static
%endif
%if ! %{with clang}
BuildRequires:  gcc%{?force_gcc_version}-c++ >= 5
%if 0%{?force_gcc_version}
#!BuildIgnore:  libgcc_s1
%endif
%endif
BuildRequires:  intltool
BuildRequires:  libxslt
%if %{with translated_manpages}
BuildRequires:  po4a
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  xz
# libraries deps
BuildRequires:  cups-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  libxml2-devel
#
%if %{with system_lua}
BuildRequires:  lua-devel >= 5.3
%endif
BuildRequires:  pugixml-devel
#
BuildRequires:  pkgconfig
%if 0%{?suse_version} != 1315 || ( 0%{?suse_version} == 1315 && 0%{?is_opensuse} )
BuildRequires:  pkgconfig(GraphicsMagick)
BuildRequires:  pkgconfig(libopenjp2)
%endif
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(colord)
BuildRequires:  pkgconfig(colord-gtk)
BuildRequires:  pkgconfig(exiv2)
%if %{with flickcurl}
BuildRequires:  pkgconfig(flickcurl)
%endif
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgphoto2)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libwebp)
%if %{with osmgpsmap}
BuildRequires:  pkgconfig(osmgpsmap-1.0)
%endif
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(sqlite3)
%if %{with system_opencl}
BuildRequires:  opencl-headers
%endif
# for the sake of simplicity we do not enforce the version here
# the package is small enough that installing it doesnt hurt
Requires:       iso-codes
#
Summary:        A virtual Lighttable and Darkroom
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Viewers

%description
darktable is a virtual lighttable and darkroom for photographers: it manages
your digital negatives in a database and lets you view them through a zoomable
lighttable. it also enables you to develop raw images and enhance them.

%if %{with basecurve_tool}
%package tools-basecurve
Summary:        The basecurve tool from tools/basecurve/
Group:          Productivity/Graphics/Viewers
Requires:       /usr/bin/convert
Requires:       dcraw
Requires:       exiftool

%description tools-basecurve
darktable is a virtual lighttable and darkroom for photographers: it manages
your digital negatives in a database and lets you view them through a zoomable
lighttable. it also enables you to develop raw images and enhance them.

This package provides the basecurve tool from tools/basecurve/.
Another option to solve the same problem might be the darktable-chart module
from the darktable package.
%endif

%package tools-noise
Summary:        The noise profiling tools to support new cameras
Group:          Productivity/Graphics/Viewers
Requires:       /usr/bin/convert
Requires:       gnuplot

%description tools-noise
darktable is a virtual lighttable and darkroom for photographers: it manages
your digital negatives in a database and lets you view them through a zoomable
lighttable. it also enables you to develop raw images and enhance them.

This package provides the noise profiling tools to add support for new cameras.

%package doc
Summary:        A virtual Lighttable and Darkroom 
Group:          Productivity/Graphics/Viewers
BuildArch:      noarch

%description doc
darktable is a virtual lighttable and darkroom for photographers: it manages
your digital negatives in a database and lets you view them through a zoomable
lighttable. it also enables you to develop raw images and enhance them.

This package provides the user manual in pdf format

%prep
%setup -q -n %{name}-%{version}
%patch -p1
%patch1 -p1
chmod -x tools/basecurve/* tools/noise/*

cp %{S:1} %{S:2} %{S:3} %{S:4} .
cp %{S:99} .

%if %{with system_opencl}
# Remove bundled OpenCL headers.
rm -rf src/external/CL
sed -i -e 's, \"external/CL/\*\.h\" , ,' src/CMakeLists.txt
%endif

%if %{with system_lua}
# Remove bundled lua
rm -rf src/external/lua/
%endif

%build
export BUILDDIR="$PWD"
%if 0%{?force_gcc_version}
export CC="gcc-%{?force_gcc_version}"
export CXX="g++-%{?force_gcc_version}"
%endif
%if %{with clang}
export CC="/usr/bin/clang"
export CXX="/usr/bin/clang++"
%endif
export _OPENCL_INCLUDE_DIR=$(clang -print-search-dirs | awk -F= '/^libra/ {print $2}' | awk -F: '{print $1 "/include"}')
%if 0%{?suse_version}
#suse branch
%cmake \
  -DCLANG_OPENCL_INCLUDE_DIR=${_OPENCL_INCLUDE_DIR} \
  %if ! %{with system_lua}
  -DDONT_USE_INTERNAL_LUA=Off \
  %endif
  %ifarch aarch64
  -DTESTBUILD_OPENCL_PROGRAMS=OFF \
  %endif
  %{cmake_options} \
   || cat CMakeFiles/CMakeError.log
make %{_smp_mflags} VERBOSE=1
cd $BUILDDIR

cd tools/basecurve
%cmake
make %{_smp_mflags} VERBOSE=1
#/ suse branch
%else
#fedora branch
mkdir %{_target_platform}
pushd %{_target_platform}
%cmake \
  %if ! %{with system_lua}
  -DDONT_USE_INTERNAL_LUA=Off \
  %endif
  %ifarch aarch64
  -DTESTBUILD_OPENCL_PROGRAMS=OFF \
  %endif  
  %{cmake_options} ..
make %{_smp_mflags} VERBOSE=1
cd $BUILDDIR

%if %{with basecurve_tool}
cd tools/basecurve
mkdir %{_target_platform}
pushd %{_target_platform}
%cmake ..
make %{_smp_mflags} VERBOSE=1
%endif
%endif
cd $BUILDDIR

%install
%if 0%{?suse_version}
# suse branch
%cmake_install
%if %{with basecurve_tool}
pushd tools/basecurve
%cmake_install
popd
%endif
%suse_update_desktop_file darktable

mkdir -p %{buildroot}%{_defaultdocdir}/%{pkg_name}/
mv %{buildroot}%{_datadir}/doc/darktable/* %{buildroot}%{_defaultdocdir}/%{pkg_name}/
#/ suse branch
%else
# fedora branch
make install DESTDIR="%{buildroot}" -C %{_target_platform}
%if %{with basecurve_tool}
make install DESTDIR="%{buildroot}" -C tools/basecurve/%{_target_platform}
%endif
#/ fedora branch
%endif
find %{buildroot}%{_libdir} -name "*.la" -delete
%find_lang darktable

cp -av %{S:2} doc/ChangeLog doc/NEWS    \
    doc/thumbnail_color_management.txt  \
    doc/TODO doc/TRANSLATORS.md         \
  %{buildroot}%{_defaultdocdir}/%{pkg_name}

mkdir -p %{buildroot}%{_defaultdocdir}/%{pkg_name}/tools/ %{buildroot}%{_datadir}/%{pkg_name}/tools/

cp -av tools/purge* tools/common.sh \
  %{buildroot}%{_datadir}/%{pkg_name}/tools/

%if %{with basecurve_tool}
mkdir -p %{buildroot}%{_datadir}/%{pkg_name}/tools/basecurve/
cp -av tools/basecurve/plot* \
  %{buildroot}%{_datadir}/%{pkg_name}/tools/basecurve/

install -D -m 0644 tools/basecurve/README.md \
  %{buildroot}%{_defaultdocdir}/%{pkg_name}/README.tools.basecurve.md
%endif

%fdupes %{buildroot}

%if 0%{?suse_version}
# on newer distros it is handled via file trigger
%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif
%else
%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
update-desktop-database &> /dev/null || :
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
%endif

%files -f darktable.lang
%defattr(-,root,root)
%doc %{_defaultdocdir}/%{pkg_name}
%exclude %{_defaultdocdir}/%{pkg_name}/*.pdf
%if %{with basecurve_tool}
%exclude %{_defaultdocdir}/%{pkg_name}/README.tools.basecurve.md
%endif
%{_bindir}/darktable
%{_bindir}/darktable-cltest
%{_bindir}/darktable-cli
%{_bindir}/darktable-generate-cache
%{_bindir}/darktable-chart
%{_bindir}/darktable-cmstest
%{_bindir}/darktable-rs-identify
%{_libdir}/darktable
%{_datadir}/applications/darktable.desktop
%{_datadir}/darktable
%exclude %{_datadir}/%{pkg_name}/tools/basecurve/
%dir %{_datadir}/appdata
%{_datadir}/appdata/darktable.appdata.xml
%{_datadir}/icons/hicolor/*/apps/darktable*
%{_mandir}/man1/darktable*.1*
%if %{with translated_manpages}
%{_mandir}/*/man1/darktable*.1*
%endif

%if %{with basecurve_tool}
%files tools-basecurve
%defattr(-,root,root)
%{_bindir}/dt-curve-tool
%{_bindir}/dt-curve-tool-helper
%{_datadir}/%{pkg_name}/tools/basecurve/
%doc %{_defaultdocdir}/%{pkg_name}/README.tools.basecurve.md
%endif

%files tools-noise
%defattr(-,root,root)
%dir %{_libexecdir}/darktable
%dir %{_libexecdir}/darktable/tools
%{_libexecdir}/darktable/tools/darktable-gen-noiseprofile
%{_libexecdir}/darktable/tools/darktable-noiseprofile
%{_libexecdir}/darktable/tools/profiling-shot.xmp
%{_libexecdir}/darktable/tools/subr.sh

%files doc
%defattr(-,root,root)
%{_defaultdocdir}/%{pkg_name}/*.pdf

%changelog
* Fri Apr 27 2018 mrueckert@suse.de
- pull from the stable branch 887d55c.patch:
  fix typo in the noise profile tools
* Tue Apr 24 2018 mrueckert@suse.de
- also track the debian packaging files as sources in the spec file
* Tue Apr 24 2018 mrueckert@suse.de
- also build and package the noise profiling tools:
  new subpackage darktable-tools-noise
* Tue Apr 24 2018 mrueckert@suse.de
- update to 2.4.3
  - New Features
  - Support for tags and ratings in the watermark module
  - Read Xmp.exif.DateTimeOriginal from XMP sidecars
  - Build and install noise tools
  - Add a script for converting .dtyle to an .xmp
  - Bugfixes
  - Don't create unneeded folders during export in some cases
  - When collecting by tags, don't select subtags
  - Fix language selection on OSX
  - Fix a crash while tethering
  - Camera support, compared to 2.4.2
  - Base Support
  - Fujifilm X-H1 (compressed)
  - Kodak EOS DCS 3
  - Olympus E-PL9
  - Panasonic DC-GX9 (4:3)
  - Sony DSC-RX1RM2
  - Sony ILCE-7M3
  - White Balance Presets
  - Sony ILCE-7M3
  - Noise Profiles
  - Canon PowerShot G1 X Mark III
  - Nikon D7500
  - Sony ILCE-7M3
* Thu Mar 22 2018 mrueckert@suse.de
- force gcc 7 on suse_version 1315 to get the new GCC flags working
  in :Update
* Wed Mar 21 2018 mrueckert@suse.de
- update to 2.4.2
  - New Features
  - Add presets to location search in map mode
  - Add timestamps to the output of `-d` command line switches
  - Add a compression level slider to the TIFF export module
  - Add native binary NetPNM loading, without using
    GraphicsMagick
  - Add a battery indicator for people running darktable on a
    laptop. This is not very portable code and disabled by
    default
  - Allow to use /? to show the help message on Windows
  - Bugfixes
  - Turn off smooth scrolling for X11/Quartz. That might help
    with oversensitive scrolling
  - Fix reading and writing of TIFFs with non-ASCII filenames on
    Windows
  - Ellipsize background job labels when too long
  - Hard code D50 white point when exporting to OpenEXR
  - Add tootips to the haze removal module
  - Fix a crash when changing lenses while tethering
  - Fix incorrect Atom CPU detection on Windows
  - Revised performance configuration
  - Don't overlay the colorbalance sliders on the left for a
    cleaner look
  - Honor local copy in copy export format
  - Make trashing of files on Windows silent
  - Fix string termination override on memmove
  - Fix a use after free and some memleaks
  - Fix a crash in PDF export
  - Fix the min color picker
  - Don't hardcode '/' in OpenCL paths on Windows
  - Camera support, compared to 2.4.1
  - Base Support
  - Canon PowerShot G1 X Mark III
  - Panasonic DMC-FZ2000 (3:2)
  - Panasonic DMC-FZ2500 (3:2)
  - Panasonic DMC-ZS100 (3:2)
  - Sony DSC-RX0
  - Sony DSC-RX10M4
  - Noise Profiles
  - Canon EOS 200D
  - Canon EOS Kiss X9
  - Canon EOS Rebel SL2
  - Canon EOS 760D
  - Canon EOS 8000D
  - Canon EOS Rebel T6s
  - Canon PowerShot G1 X Mark II
  - Canon PowerShot G9 X
  - Fujifilm X100F
  - Nikon D850
  - Panasonic DC-G9
  - Panasonic DMC-GF6
  - Panasonic DMC-LX10
  - Panasonic DMC-LX15
  - Panasonic DMC-LX9
  - Panasonic DMC-TZ70
  - Panasonic DMC-TZ71
  - Panasonic DMC-ZS50
  - Translations
  - Dutch
  - French
  - German
  - Hungarian
  - Italian
* Mon Jan 22 2018 mrueckert@suse.de
- update to 2.4.1
  - New Features
  - Allow to select the GUI language in the preferences
  - Add a filter rule to the collect module to find locally
    copied images
  - Add favourite toggle to darkroom modules' right click popup
  - Allow blending/masking in the hot pixels module
  - Add keyboard shortcuts to zoom and pan an image in darkroom.
    Panning uses the arrow keys, zooming defaults to `ctrl-` and
    `ctrl+`. Use `alt` and `ctrl` to change the step size of
    panning.
  - Some minor speedups in the grain module
  - Handling stdout on Windows: do not redirect stdout for simple
    command line arguments (`--help` and `--version`)
  - On Windows, show the location of the log file in the help
    message
  - Enable searching in the more modules list – click into the
    list to give focus to it, then start typing. The default GTK
    shortcut `ctrl-f` doesn't work as it's used for filmstrip
    already
  - Add a debug print when compiling OpenCL kernels
  - Bugfixes
  - Use the configured overwrite color profile when exporting
    from Lua – this broke GIMP integration
  - Support presets with `<` in their name
  - Fix export to non-existing path with `\` as the path
    separator on Windows
  - Don't insist on the db being locked when it doesn't even
    exist
  - Don't touch the mix slider when resetting the curve in color
    zones
  - Fix a bug in the exposure module that would only allow
    corrections of up to 10 stops
  - Fix custom shortcuts with `shift` modifier
  - Properly ellipsize text in the recently used collections list
  - Fix exported galeries with filenames containing a `'`
  - Fix finding mipmaps cache folder in `purge_from_cache.sh`
    script
  - Fix a crash in the recently used collections list due to a
    broken config file
  - Set the sqlite threading mode to Serialized
  - Fix old export presets using OpenEXR
  - Fix building with clang on Windows
  - Changed Dependencies
  - iso-codes version 3.66 or newer is suggested for a nicer list
    of translations in the preferences.
  - Camera support, compared to 2.4.0 Warning: support for Nikon
    NEF 'lossy after split' raws was unintentionally broken due to
    the lack of such samples. Please see
    [this post](https://discuss.pixls.us/t/nikon-a-specific-raw-sample-wanted/5483?u=lebedevri)
    for more details. If you have affected raws, please contribute
    samples!
  - Base Support
  - Panasonic DC-G9 (4:3)
  - Paralenz Dive Camera (chdk)
  - Pentax KP
  - Sjcam SJ6 LEGEND (chdk-b, chdk-c)
  - White Balance Presets
  - Leaf Credo 40
  - Nikon D3400
  - Olympus E-M1MarkII
  - Panasonic DC-G9
  - Sony ILCE-7RM3
  - Noise Profiles
  - Canon EOS 750D
  - Canon EOS Kiss X8i
  - Canon EOS Rebel T6i
  - Canon EOS 77D
  - Canon EOS 9000D
  - Canon EOS M100
  - Canon EOS M6
  - Sony DSC-RX100M4
  - YI TECHNOLOGY M1
  - Translations
  - Czech
  - Dutch
  - French
  - German
  - Hebrew
  - Hungarian
  - Italian
  - Slovenian
* Sun Dec 24 2017 mrueckert@suse.de
- merge back in the fedora support
* Sun Dec 24 2017 mrueckert@suse.de
- drop llvm5.patch
- modified darktable-old-glib.patch to apply cleanly again
* Sun Dec 24 2017 mrueckert@suse.de
- update to 2.4.0
  - The maintainership of the RawSpeed library was transferred to
    the darktable project. The work on code cleanup, hardening,
    modernization, simplification and testing is ongoing.
  - Almost 3 thousand commits to darktable+rawspeed since 2.2.0
  - 273 pull requests handled
  - 340+ issues closed
  - Updated user manual is coming soon™
  - The Big Ones
  - A new module for haze removal
  - The local contrast module can now be pushed much further, it
    also got a new [local
    laplacian](https://www.darktable.org/2017/11/local-laplacian-pyramids/)
    mode
  - Add undo support for masks and more intelligent grouping of
    undo steps
  - Blending now allows to display individual channels using
    false colors
  - darktable now supports loading Fujifilm compressed RAFs
  - darktable now supports loading floating point HDR DNGs as
    written by HDRMERGE
  - We also added channel specific blend modes for Lab and RGB
    color spaces
  - The base curve module allows for more control of the
    [exposure
    fusion](https://www.darktable.org/2016/08/compressing-dynamic-range-with-exposure-fusion/)
    feature using the newly added bias slider
  - The tonecurve module now supports auto colour adjustment in
    RGB
  - Add absolute color input as an option to the color look up
    table module
  - A new X-Trans demosaicing algorithm, Frequency Domain Chroma,
    was implemented.
  - You can now choose from pre-defined scheduling profiles for
    OpenCL
  - Speaking of OpenCL, darktable now allows to force-use OpenCL
    for a specific pixelpipe
  - XMP sidecar files are no longer written to disk when the
    content didn't actually change. That mostly helps with
    network storage and backup systems that use files' time
    stamps
  - New Features And Changes
  - Show a dialog window that tells when locking the
    database/library failed
  - Don't shade the whole region on the map when searching for a
    location. Instead just draw a border around it.
  - Also in map mode: Clear the search list and map indicators
    when resetting the search module.
  - With OsmGPSMap newer than version 1.1.0 (i.e., anything
    released after that OsmGPSMap version) the map will show
    copyright info.
  - Running jobs with a progressbar (mostly import and export)
    will show that progress bar ontop the window entry in your
    task bar – if the system supports it. It should work on
    GNOME, KDE and Windows at least.
  - Add bash like string replacement for variables (export,
    watermark, session settings)
  - Add a preferences option to ask before removing empty dirs
  - The "colorbalance" module got a lot faster, thanks to SSE
    optimized code
  - Make gradient sliders a little more colorful
  - Make PNG compression level used for exporting configurable
  - On OSX, load single images from command line or via drag&drop
    in darkroom mode
  - Add an option to omit the intermediate tag hierarchy in
    exported files and only add the last level
  - In the watermark module, sort the list of SVG files and omit
    the file extension
  - Support XYZ as a proofing profile
  - Local contrast now got a new slider to set the midtone range
  - darktable got two new helper scripts (those are not installed
    by default, grab them from [the sources](https://github.com/darktable-org/darktable/tree/master/tools))
  - One to purge thumbnails that no longer have an associated
    image in the database,
  - and a second script that uses inotify to watch a folder
    for new files to open them in a running darktable
    instance.
  - In the curve editors of base curve and tone curve you can now
    delete nodes with a right click and see coordinates of nodes
    while editing. Note that you can use keyboard modifiers
    `ctrl` and `shift` to change the precision of your changes
  - Creating a new instance of a module can now be done with a
    quick click of the middle mouse button on the multi-instance
    icon
  - New darktable installations on computers with more than 8 Gb
    of memory will now by default use half of that per module
  - Several background colors and the brush color are now
    configurable in the CSS
  - Some new cameras can bump the ISO level to insane highs. We
    try to follow as good as we can by no longer limiting it to
    51200 in the GUI
  - Base curve and the highlights module now support multiple
    instances and use blending and masks
  - Having the `1` key toggle between 1 and 0 stars wasn't very
    popular with many people. You can disable that extra feature
    and have it behave like the other rating shortcuts now
  - You can decide if you want to be asked before resetting the
    history stacks of images from the lighttable
  - The grain module was slightly changed to have a more
    pleasing, photographic-paper like appearance
  - Using the color look up table module you can now convert your
    images to monochrome, honoring the Helmholtz-Kohlrausch
    effect
  - Support basic import of Lightroom 7 settings
  - Change the styling of insensitive bauhaus widgets
  - Don't hide the mode combobox in the exposure module, just
    disable it
  - Read primaries and whitepoint from .hdr files and default to
    those as the input color profile
  - Some more small improvements were made
  - Bugfixes
  - Fix the problem with rating images by accident when moving
    the mouse while typing an image size in the export module
  - Fix several oddities in folder and tag mode of the collect
    module
  - Print mode's color profile settings no longer interact with
    the export module
  - Update the style lists when importing a style
  - Fix some bugs with multiple module instances used in a style
  - On OSX only the main window should be fullscreen, not the
    popups
  - Some speedups with VERY big libraries or having A LOT OF tags
  - Significantly speed up tagging many images
  - Fix searching locations using OpenStreetMap
  - Fix partial copies of large files in "import from camera"
  - Fix a crash in the import dialog when using Lua to add
    widgets there
  - Fix some false-positive warnings about another running
    darktable instance and it having locked the databases
  - No longer switch to the favourite modules group when
    duplicating one of its modules
  - Fix loading of XYZ files
  - Fix Lab export when the profile was set from the lighttable
  - Create temporary snapshot files with mode 0600 to stop other
    people looking at them
  - Fix several bugs with Wayland. However, there are still
    issues, so darktable will prefer XWayland
  - Google deprecated the Picasa Web API so it's no longer
    possible to create G+ albums
  - Fix the default for sliders with target not being "red" in
    the channel mixer
  - Fix the removal of directories
  - Make the escape key cancel history dialogs
  - Block keyboard accels when editing camera controls
  - Properly delete XMP sidecars
  - Make sure that the rating set in darktable is used for the
    exported file, not something set inside the raw file
  - Don't re-write all XMP files when detaching a tag
  - Sync XMPs when a tag is removed from the database
  - Sync XMPs after a tag is attached/detached via the Lua API
  - Bail out of darktable-cli when the XMP file is not readable
  - Show ratings on zoomable lighttable without a delay
  - Rely on CUPS color management when printing without
    configuring any color profile in darktable
  - Fix spurious segfault in local contrast
  - Make calls to exiv2's readMetadata thread safe to not crash
    randomly
  - Properly read Lightroom XMPs on systems with `,` as the
    decimal separator
  - Fix setting the PNG bit depth from the gui
  - Many more bugs got fixed
  - Lua
  - darktable now uses Lua 5.3. The bundled copy got updated
    accordingly
  - Add dt.print_log. It's like print_error but without the ERROR
    prefix
  - Reorder callback parameters for intermediate export image:
    add the actual image to the parameters of the event
  - Call lua post-import-image event synchronously
  - Add darktable.configuration.running_os to detect the OS
    darktable is running on
  - New widget type: section_label, adds a label which looks like
    a section change
  - Changed Dependencies
  - CMake 3.1 is now required
  - In order to compile darktable you now need at least
    gcc-5.0+/clang-3.4+
  - ZLIB is now required for the DNG Deflate compressed raw
    support
  - darktable now uses Lua 5.3
  - Camera support, compared to 2.2.0
    Warning: support for Nikon NEF 'lossy after split' raws was
    unintentionally broken due to the lack of such samples. Please
    see [this post](https://discuss.pixls.us/t/nikon-a-specific-raw-sample-wanted/5483?u=lebedevri)
    for more details. If you have affected raws, please contribute
    samples!
  - Base Support
  - Canon EOS 200D
  - Canon EOS Kiss X9
  - Canon EOS Rebel SL2
  - Canon EOS 6D Mark II (sRaw1, sRaw2)
  - Canon EOS 77D
  - Canon EOS 9000D
  - Canon EOS 800D
  - Canon EOS Kiss X9i
  - Canon EOS Rebel T7i
  - Canon EOS M100
  - Canon EOS M5
  - Canon EOS M6
  - Canon PowerShot G9 X Mark II
  - Canon PowerShot SX40 HS (dng)
  - Fujifilm GFX 50S (compressed)
  - Fujifilm X-A3
  - Fujifilm X-E2S
  - Fujifilm X-E3 (compressed)
  - Fujifilm X-Pro2 (compressed)
  - Fujifilm X-T2 (compressed)
  - Fujifilm X-T20 (compressed)
  - Fujifilm X100F (compressed)
  - GITUP GIT2P (chdk-a, chdk-b)
  - Kodak EasyShare Z980
  - LG D855 (dng)
  - LG H815 (dng)
  - LG Nexus 5X (dng)
  - LG US996 (dng)
  - LG VS995 (dng)
  - Leica D-LUX (Typ 109) (4:3, 3:2, 16:9, 1:1)
  - Leica X2 (dng)
  - Nikon COOLPIX B700 (12bit-uncompressed)
  - Nikon D500 (14bit-uncompressed, 12bit-uncompressed)
  - Nikon D5600 (12bit-compressed, 12bit-uncompressed,
    14bit-compressed, 14bit-uncompressed)
  - Nikon D7500 (12bit-compressed, 14bit-compressed)
  - Nikon D850 (12bit-compressed, 12bit-uncompressed,
    14bit-compressed, 14bit-uncompressed)
  - Nikon LS-5000 (dng)
  - Nokia Lumia 1020 (dng)
  - Olympus E-M10 Mark III
  - Olympus E-M1MarkII
  - Olympus TG-5
  - Panasonic DC-FZ82 (4:3)
  - Panasonic DMC-FZ80 (4:3)
  - Panasonic DMC-FZ85 (4:3)
  - Panasonic DC-GH5 (4:3)
  - Panasonic DC-FZ91 (4:3)
  - Panasonic DC-FZ92 (4:3)
  - Panasonic DC-FZ93 (4:3)
  - Panasonic DC-TZ90 (4:3)
  - Panasonic DC-ZS70 (4:3)
  - Panasonic DMC-FZ330 (4:3)
  - Panasonic DMC-GF6 (16:9, 3:2, 1:1)
  - Panasonic DMC-TZ61 (4:3, 3:2, 1:1, 16:9)
  - Panasonic DMC-ZS40 (4:3, 3:2, 1:1, 16:9)
  - Panasonic DMC-TZ80 (4:3)
  - Panasonic DMC-TZ81 (4:3)
  - Panasonic DMC-TZ85 (4:3)
  - Panasonic DMC-ZS60 (4:3)
  - Pentax K-5 (dng)
  - Pentax K-r (dng)
  - Pentax K10D (dng)
  - Phase One IQ140
  - Samsung G920F
  - Samsung G935F
  - Samsung GX10
  - Sony ILCE-6500
  - Sony ILCE-7RM3
  - Sony ILCE-9
  - White Balance Presets
  - Canon EOS 6D Mark II
  - Fujifilm X-T20
  - Fujifilm X100F
  - Nikon 1 AW1
  - Nikon Coolpix A
  - Panasonic DMC-GX80
  - Panasonic DMC-GX85
  - Panasonic DMC-TZ100
  - Panasonic DMC-TZ101
  - Panasonic DMC-TZ110
  - Panasonic DMC-ZS110
  - Pentax K-3 II
  - Noise Profiles
  - Canon EOS 1300D
  - Canon EOS Kiss X80
  - Canon EOS Rebel T6
  - Canon EOS 5D Mark IV
  - Canon EOS 6D Mark II
  - Canon EOS M5
  - Canon PowerShot G16
  - Canon PowerShot G3 X
  - Canon PowerShot G7 X Mark II
  - Canon PowerShot G9 X Mark II
  - Fujifilm X-M1
  - Fujifilm X-Pro1
  - Fujifilm X-Pro2
  - Fujifilm X-T20
  - Leica X2
  - Nikon Coolpix A
  - Nikon D2X
  - Nikon D3000
  - Nikon D3400
  - Nikon D4
  - Nikon D500
  - Olympus E-M1MarkII
  - Olympus E-P5
  - Panasonic DMC-FZ200
  - Panasonic DMC-FZ300
  - Panasonic DMC-G7
  - Panasonic DMC-G70
  - Panasonic DMC-G8
  - Panasonic DMC-G80
  - Panasonic DMC-G81
  - Panasonic DMC-G85
  - Panasonic DMC-GX80
  - Panasonic DMC-GX85
  - Panasonic DMC-LX100
  - Panasonic DMC-TZ100
  - Panasonic DMC-TZ101
  - Panasonic DMC-TZ110
  - Panasonic DMC-ZS110
  - Pentax K-70
  - Sony DSC-RX100M5
  - Sony ILCA-68
  - Sony ILCE-5000
  - Sony ILCE-6500
  - Sony ILCE-7RM3
  - Translations
  - Catalan
  - Czech
  - Danish
  - Dutch
  - French
  - German
  - Greek
  - Hebrew
  - Hungarian
  - Italian
  - Japanese
  - Polish
  - Russian
  - Slovak
  - Slovenian
  - Spanish
  - Swedish
  - Ukrainian
* Mon Dec 18 2017 mrueckert@suse.de
- added llvm5.patch: list of llvm version is hardcoded and llvm 5,
  while it works for building, wasn't searched for.
- package the darktable basecurve tool in a new subpackage
- make sure pdf documentation never ends up in the main package
- drop non suse support
- drop ix86 support. 64bit only from now on.
* Mon Dec 18 2017 mrueckert@suse.de
- update to 2.4.0.rc2
  - The maintainership of the RawSpeed library was transferred to
    the darktable project. The work on code cleanup, hardening,
    modernization, simplification and testing is ongoing.
  - Well over 2 thousand commits to darktable+rawspeed since 2.2.0
  - 244 pull requests handled
  - 320+ issues closed
  - Updated user manual is coming soon™
  - The Big Ones
  - A new module for haze removal
  - The local contrast module can now be pushed much further, it
    also got a new local laplacian mode
  - Add undo support for masks and more intelligent grouping of
    undo steps
  - Blending now allows to display individual channels using
    false colors
  - darktable now supports loading Fujifilm compressed RAFs
  - darktable now supports loading floating point HDR DNGs as
    written by HDRMERGE
  - We also added channel specific blend modes for Lab and RGB
    color spaces
  - The base curve module allows for more control of the exposure
    fusion feature using the newly added bias slider
  - The tonecurve module now supports auto colour adjustment in
    RGB
  - Add absolute color input as an option to the color look up
    table module
  - A new X-Trans demosaicing algorithm, Frequency Domain Chroma,
    was implemented.
  - You can now choose from pre-defined scheduling profiles for
    OpenCL
  - Speaking of OpenCL, darktable now allows to force-use OpenCL
    for a specific pixelpipe
  - Xmp sidecar files are no longer written to disk when the
    content didn't actually change. That mostly helps with
    network storage and backup systems that use files' time
    stamps
  - New Features And Changes
  - Show a dialog window that tells when locking the
    database/library failed
  - Don't shade the whole region on the map when searching for a
    location. Instead just draw a border around it.
  - Also in map mode: Clear the search list and map indicators
    when resetting the search module.
  - With OsmGPSMap newer than version 1.1.0 (i.e., anything
    released after that OsmGPSMap version) the map will show
    copyright info.
  - Running jobs with a progressbar (mostly import and export)
    will show that progress bar ontop the window entry in your
    task bar – if the system supports it. It should work on
    GNOME, KDE and Windows at least.
  - Add bash like string replacement for variables (export,
    watermark, session settings).
  - Add a preferences option to ask before removing empty dirs
  - The "colorbalance" module got a lot faster, thanks to SSE
    optimized code
  - Make gradient sliders a little more colorful
  - Make PNG compression level used for exporting configurable
  - On OSX, load single images from command line or via drag&drop
    in darkroom mode
  - Add an option to omit the intermediate tag hierarchy in
    exported files and only add the last level
  - In the watermark module, sort the list of SVG files and omit
    the file extension
  - Support XYZ as a proofing profile
  - Local contrast now got a new slider to set the midtone range
  - darktable got two new helper scripts (those are not installed
    by default, grab them from the sources): One to purge
    thumbnails that no longer have an associated image in the
    database, and a second script that uses inotify to watch a
    folder for new files to open them in a running darktable
    instance.
  - In the curve editors of base curve and tone curve you can now
    delete nodes with a right click and see coordinates of nodes
    while editing. Note that you can use keyboard modifiers ctrl
    and shift to change the precision of your changes
  - Creating a new instance of a module can now be done with a
    quick click of the middle mouse button on the multi-instance
    icon
  - New darktable installations on computers with more than 8 Gb
    of memory will now by default use half of that per module
  - Several background colors and the brush color are now
    configurable in the CSS
  - Some new cameras can bump the ISO level to insane highs. We
    try to follow as good as we can by no longer limiting it to
    51200 in the GUI
  - Base curve and the highlights module now support multiple
    instances and use blending and masks
  - Having the `1` key toggle between 1 and 0 stars wasn't very
    popular with many people. You can disable that extra feature
    and have it behave like the other rating shortcuts now
  - You can decide if you want to be asked before resetting the
    history stacks of images from the lighttable
  - The grain module was slightly changed to have a more
    pleasing, photographic-paper like appearance
  - Using the color look up table module you can now convert your
    images to monochrome, honoring the Helmholtz-Kohlrausch
    effect
  - Some more small improvements were made
  - Support basic import of Lightroom 7 settings
  - Change the styling of insensitive bauhaus widgets
  - Don't hide the mode combobox in the exposure module, just
    disable it
  - Bugfixes
  - Fix the problem with rating images by accident when moving
    the mouse while typing an image size in the export module
  - Fix several oddities in folder and tag mode of the collect
    module.
  - Print mode's color profile settings no longer interact with
    the export module
  - Update the style lists when importing a style
  - Fix some bugs with multiple module instances used in a style
  - On OSX only the main window should be fullscreen, not the
    popups
  - Some speedups with VERY big libraries or having A LOT OF tags
  - Significantly speed up tagging many images
  - Fix searching locations using OpenStreetMap
  - Fix partial copies of large files in "import from camera"
  - Fix a crash in the import dialog when using Lua to add
    widgets there
  - Fix some false-positive warnings about another running
    darktable instance and it having locked the databases
  - No longer switch to the favourite modules group when
    duplicating one of its modules
  - Fix loading of XYZ files
  - Fix Lab export when the profile was set from the lighttable
  - Create tmp snapshot files with mode 0600 to stop other people
    looking at them
  - Fix several bugs with Wayland. However, there are still
    issues, so darktable will prefer XWayland
  - Google deprecated the Picasa Web API so it's no longer
    possible to create G+ albums
  - Fix the default for sliders with target not being "red" in
    the channel mixer
  - Fix the removing of directories
  - Make the escape key cancel history dialogs
  - Block keyboard accels when editing camera controls
  - Properly delete XMP sidecars
  - Make sure that the rating set in darktable is used for the
    exported file, not something set inside the raw file
  - Don't re-write all XMP files when detaching a tag
  - Sync XMPs when a tag is removed from the database
  - Sync XMPs after a tag is attached/detached via the Lua API
  - Bail out of darktable-cli when the XMP file is not readable
  - Show ratings on zoomable lighttable without a delay
  - Rely on CUPS color management when printing without
    configuring any color profile in darktable
  - Many more bugs got fixed
  - Fix spurious segfault in local contrast
  - Make calls to exiv2's readMetadata thread safe to not crash
    randomly
  - Lua
  - darktable now uses Lua 5.3. The bundled copy got updated
    accordingly
  - Add dt.print_log. It's like print_error but without the ERROR
    prefix
  - Reorder callback parameters for intermediate export image:
    add the actual image to the parameters of the event
  - Call lua post-import-image event synchronously
  - Add darktable.configuration.running_os to detect the OS
    darktable is running on
  - New widget type: section_label, adds a label which looks like
    a section change
  - Changed Dependencies
  - CMake 3.1 is now required.
  - In order to compile darktable you now need at least
    gcc-4.9+/clang-3.4+, and gcc-5.0+ is *highly* recommended.
  - ZLIB is now required for the DNG Deflate compressed raw
    support.
  - darktable now uses Lua 5.3
  - Camera support, compared to 2.2.0
    Warning: support for Nikon NEF 'lossy after split' raws was
    unintentionally broken due to the lack of such samples. Please
    see https://discuss.pixls.us/t/nikon-a-specific-raw-sample-wanted/5483
    for more details. If you have affected raws, please contribute samples!
  - Base Support
  - Canon EOS 200D
  - Canon EOS Kiss X9
  - Canon EOS Rebel SL2
  - Canon EOS 6D Mark II (sRaw1, sRaw2)
  - Canon EOS 77D
  - Canon EOS 9000D
  - Canon EOS 800D
  - Canon EOS Kiss X9i
  - Canon EOS Rebel T7i
  - Canon EOS M100
  - Canon EOS M5
  - Canon EOS M6
  - Canon PowerShot G9 X Mark II
  - Canon PowerShot SX40 HS (dng)
  - Fujifilm GFX 50S (compressed)
  - Fujifilm X-A3
  - Fujifilm X-E2S
  - Fujifilm X-E3 (compressed)
  - Fujifilm X-Pro2 (compressed)
  - Fujifilm X-T2 (compressed)
  - Fujifilm X-T20 (compressed)
  - Fujifilm X100F (compressed)
  - GITUP GIT2P (chdk-a, chdk-b)
  - Kodak EasyShare Z980
  - LG D855 (dng)
  - LG H815 (dng)
  - LG Nexus 5X (dng)
  - LG US996 (dng)
  - LG VS995 (dng)
  - Leica D-LUX (Typ 109) (4:3, 3:2, 16:9, 1:1)
  - Leica X2 (dng)
  - Nikon COOLPIX B700 (12bit-uncompressed)
  - Nikon D500 (14bit-uncompressed, 12bit-uncompressed)
  - Nikon D5600 (12bit-compressed, 12bit-uncompressed,
    14bit-compressed, 14bit-uncompressed)
  - Nikon D7500 (12bit-compressed, 14bit-compressed)
  - Nikon D850 (12bit-compressed, 12bit-uncompressed,
    14bit-compressed, 14bit-uncompressed)
  - Nikon LS-5000 (dng)
  - Nokia Lumia 1020 (dng)
  - Olympus E-M10 Mark III
  - Olympus E-M1MarkII
  - Olympus TG-5
  - Panasonic DC-FZ82 (4:3)
  - Panasonic DMC-FZ80 (4:3)
  - Panasonic DMC-FZ85 (4:3)
  - Panasonic DC-GH5 (4:3)
  - Panasonic DC-FZ91 (4:3)
  - Panasonic DC-FZ92 (4:3)
  - Panasonic DC-FZ93 (4:3)
  - Panasonic DC-TZ90 (4:3)
  - Panasonic DC-ZS70 (4:3)
  - Panasonic DMC-FZ330 (4:3)
  - Panasonic DMC-GF6 (16:9, 3:2, 1:1)
  - Panasonic DMC-TZ61 (4:3, 3:2, 1:1, 16:9)
  - Panasonic DMC-ZS40 (4:3, 3:2, 1:1, 16:9)
  - Panasonic DMC-TZ80 (4:3)
  - Panasonic DMC-TZ81 (4:3)
  - Panasonic DMC-TZ85 (4:3)
  - Panasonic DMC-ZS60 (4:3)
  - Pentax K-5 (dng)
  - Pentax K-r (dng)
  - Pentax K10D (dng)
  - Phase One IQ140
  - Samsung G920F
  - Samsung G935F
  - Samsung GX10
  - Sony ILCE-6500
  - Sony ILCE-7RM3
  - Sony ILCE-9
  - White Balance Presets
  - Canon EOS 6D Mark II
  - Fujifilm X-T20
  - Fujifilm X100F
  - Nikon 1 AW1
  - Nikon Coolpix A
  - Panasonic DMC-GX80
  - Panasonic DMC-GX85
  - Panasonic DMC-TZ100
  - Panasonic DMC-TZ101
  - Panasonic DMC-TZ110
  - Panasonic DMC-ZS110
  - Pentax K-3 II
  - Noise Profiles
  - Canon EOS 1300D
  - Canon EOS Kiss X80
  - Canon EOS Rebel T6
  - Canon EOS 5D Mark IV
  - Canon EOS 6D Mark II
  - Canon EOS M5
  - Canon PowerShot G16
  - Canon PowerShot G3 X
  - Canon PowerShot G7 X Mark II
  - Canon PowerShot G9 X Mark II
  - Fujifilm X-M1
  - Fujifilm X-Pro1
  - Fujifilm X-T20
  - Leica X2
  - Nikon Coolpix A
  - Nikon D2X
  - Nikon D3000
  - Nikon D3400
  - Nikon D4
  - Nikon D500
  - Olympus E-M1MarkII
  - Olympus E-P5
  - Panasonic DMC-FZ200
  - Panasonic DMC-FZ300
  - Panasonic DMC-G7
  - Panasonic DMC-G70
  - Panasonic DMC-G8
  - Panasonic DMC-G80
  - Panasonic DMC-G81
  - Panasonic DMC-G85
  - Panasonic DMC-GX80
  - Panasonic DMC-GX85
  - Panasonic DMC-LX100
  - Panasonic DMC-TZ100
  - Panasonic DMC-TZ101
  - Panasonic DMC-TZ110
  - Panasonic DMC-ZS110
  - Pentax K-70
  - Sony DSC-RX100M5
  - Sony ILCA-68
  - Sony ILCE-5000
  - Sony ILCE-6500
  - Updated Translations
  - Catalan
  - Dutch
  - French
  - German
  - Hebrew
  - Hungarian
  - Polish
  - Russian
  - Spanish
* Tue Oct 10 2017 mrueckert@suse.de
- add BR for lcms2
* Sun May 28 2017 mrueckert@suse.de
- update to 2.2.5
  - New features:
  - When appending EXIF data to an exported image, do not fail if reading of EXIF from the original file fails
  - Support XYZ as proofing profile
  - Clear DerivedFrom from XMP before writing it
  - bauhaus: when using soft bounds, keep slider step constant
  - Bugfixes:
  - Some GCC7 build fixes
  - cmstest: fix crash when missing XRandR extension.
  - Fix crash in Lua libs when collapsing libs
  - Mac packaging: some fixes
  - RawSpeed: TiffIFD: avoid double-free
  - Fix a few alloc-dealloc mismatches
  - Base Support:
  - Canon EOS 77D
  - Canon EOS 9000D
  - Nikon D500 (14bit-uncompressed, 12bit-uncompressed)
  - Nikon D5600 (12bit-compressed, 12bit-uncompressed, 14bit-compressed, 14bit-uncompressed)
  - Panasonic DC-FZ82 (4:3)
  - Panasonic DMC-FZ80 (4:3)
  - Panasonic DMC-FZ85 (4:3)
  - Panasonic DC-GH5 (4:3)
  - White Balance Presets:
  - Pentax K-3 II
  - Noise Profiles:
  - Nikon D500
  - Panasonic DMC-FZ300
  - Panasonic DMC-LX100
  - Pentax K-70
  - Sony ILCE-5000
- refreshed darktable-old-glib.patch
* Thu Apr 27 2017 davejplater@gmail.com
- Build with opencl from 42.1 upwards.
- Copy README.openSUSE to documentation dir instead of french pdf.
- Make %%fdupes create symlinks.
* Mon Apr  3 2017 mrueckert@suse.de
- update to 2.2.4
  - New features:
  - Better brush trace handing of opacity to get better control.
  - tools: Add script to purge stale thumbnails
  - tools: A script to watch a folder for new images
  - Bugfixes:
  - DNG: fix camera name demangling. It used to report some wrong
    name for some cameras.
  - When using wayland, prefer XWayland, because native Wayland
    support is not fully functional yet
  - EXIF: properly handle image orientation '2' and '4' (swap
    them)
  - OpenCL: a few fixes in profiled denoise, demosaic and
    colormapping
  - tiling: do not process uselessly small end tiles
  - masks: avoid assertion failure in early phase of path
    generation,
  - masks: reduce risk of unwanted self-finalization of small
    path shapes
  - Fix rare issue when expanding $() variables in import/export
    string
  - Camera import: fix ignore_jpg setting not having an effect
  - Picasa web exporter: unbreak after upstream API change
  - collection: fix query string for folders ( 'a' should match
    'a/b' and 'a/c', but not 'ac/' )
  - Base Support:
  - Fujifilm X-T20 (only uncompressed raw, at the moment)
  - Fujifilm X100F (only uncompressed raw, at the moment)
  - Nikon COOLPIX B700 (12bit-uncompressed)
  - Olympus E-M1MarkII
  - Panasonic DMC-TZ61 (4:3, 3:2, 1:1, 16:9)
  - Panasonic DMC-ZS40 (4:3, 3:2, 1:1, 16:9)
  - Sony ILCE-6500
  - Noise Profiles:
  - Canon PowerShot G7 X Mark II
  - Olympus E-M1MarkII
  - Lge Nexus 5X
* Tue Jan 31 2017 mrueckert@suse.de
- update to 2.2.3
  - Fix fatal crash when generating preview for medium megapixel
    count (~16MP) Bayer images
  - Propely subtract black levels: respect the even/odd -ness of
    the raw crop origin point
  - Collection module: fix a few ui quirks
- drop f7bc2b3338832a42629cdfaa691b5c921df0701c.patch
  included in update
* Mon Jan 30 2017 mrueckert@suse.de
- added f7bc2b3338832a42629cdfaa691b5c921df0701c.patch
  imageop_math: fix Bayer downscale bounds. Fixes #11486
* Mon Jan 30 2017 mrueckert@suse.de
- update to 2.2.2:
  - New features:
  - color look up table module: include preset for
    helmholtz/kohlrausch monochrome
  - Lens module: re-enable tiling
  - Darkroom: fix some artefacts in the preview image (not the
    main view!)
  - DNG decoder: support reading one more white balance encoding
    method
  - Mac: display an error when too old OS version is detected
  - Some documentation and tooltips updates
  - Bugfixes:
  - Main view no longer grabs focus when mouse enters it.
    Prevents accidental catastrophic image rating loss.
  - OSX: fix bauhaus slider popup keyboard input
  - Don't write all XMP when detaching tag
  - OSX: don't do PPD autodetection, gtk did their thing again.
  - Don't show db lock popup when dbus is used to start darktable
  - Actually delete duplicate's XMP when deleting duplicated
    image
  - Ignore UTF-8 BOM in GPX files
  - Fix import of LR custom tone-curve
  - Overwrite Xmp rating from raw when exporting
  - Some memory leak fixes
  - Lua: sync XMPs after some tag manipulations
  - Explicitly link against math library
  - Base Support:
  - Canon PowerShot SX40 HS (dng)
  - Fujifilm X-E2S
  - Leica D-LUX (Typ 109) (4:3, 3:2, 16:9, 1:1)
  - Leica X2 (dng)
  - Nikon LS-5000 (dng)
  - Nokia Lumia 1020 (dng)
  - Panasonic DMC-GF6 (16:9, 3:2, 1:1)
  - Pentax K-5 (dng)
  - Pentax K-r (dng)
  - Pentax K10D (dng)
  - Sony ILCE-6500
  - Noise Profiles:
  - Fujifilm X-M1
  - Leica X2
  - Nikon Coolpix A
  - Panasonic DMC-G8
  - Panasonic DMC-G80
  - Panasonic DMC-G81
  - Panasonic DMC-G85
* Sat Jan 14 2017 mrueckert@suse.de
- update to 2.2.1:
  - New features:
  - Show a dialog window that tells when locking the
    database/library failed
  - Ask before deleting history stack from lightable.
  - preferences: make features that are not available (greyed
    out) more obvious
  - Bugfixes:
  - Always cleanup undo list before entering darkroom view. Fixes
    crash when using undo after re-entering darkroom
  - Darkroom: properly delete module instances. Fixes rare
    crashes after deleting second instance of module.
  - Levels and tonecurve modules now also use 256 bins.
  - Rawoverexposed module: fix visualization when a camera custom
    white balance preset is used
* Sat Jan 14 2017 mrueckert@suse.de
- fix building with openjpeg2
* Fri Dec 23 2016 mrueckert@suse.de
- update to 2.2.0:
  Well over 2k commits since 2.0.0
  - The Big Ones:
  - Add new automatic perspective correction module
    (https://www.darktable.org/2016/03/a-new-module-for-automatic-perspective-correction/)
  - Liquify tool for all your fancy pixel moving
    (https://www.darktable.org/2016/04/liquify-liquify/)
  - A new image module to use a Color Look Up Table (CLUT) to
    change colors in the image
    (https://www.darktable.org/2016/05/colour-manipulation-with-the-colour-checker-lut-module/)
  - In Highlight reconstruction module, the mode LCh
    reconstruction was completely rewritten, and is no longer
    useless!
  - A new tool, darktable-chart, that goes along with the CLUT
    module, to create styles for the latter
  - Exposure fusion in the basecurve module to lower the dynamic
    range of images
    (https://www.darktable.org/2016/08/compressing-dynamic-range-with-exposure-fusion/)
  - Add new raw overexposure indication
    (https://www.darktable.org/2016/10/raw-overexposed/)
  - Darkroom: the preview (in top-left corner) is now no longer
    pre-demosaiced (but just downscaled without demosaicing it at
    the same time), thus the preview, color picker, histogram
    show the proper results, especially when there is highlight
    clipping.
  - Quite Interesting Changes:
  - Split the database into a library containing images and a
    general one with styles, presets and tags. That allows having
    access to those when for example running with a :memory:
    library
  - Support running on platforms other than x86 (64bit
    little-endian, currently ARM64 only)
    (https://www.darktable.org/2016/04/running-on-non-x86-platforms/)
  - darktable is now happy to use smaller stack sizes (no less
    than 256Kb). That should allow using musl libc
  - Allow darktable-cli to work on directories
  - Allow to import/export tags from Lightroom keyword files
  - Allow using modifier keys to modify the step for sliders and
    curves. Defaults: Ctrl - x0.1; Shift - x10
  - Allow using the [keyboard] cursor keys to interact with
    sliders, comboboxes and curves; modifiers apply too
  - Support presets in "more modules" so you can quickly switch
    between your favorite sets of modules shown in the GUI
  - Add range operator and date compare to the collection module
  - Add basic undo/redo support for the darkroom (masks are not
    accounted !)
  - Support the Exif date and time when importing photos from
    camera
  - Input color profile module, when profile is just matrix (and
    linear curve), is 1/3 faster now.
  - Rudimentary CYGM and RGBE color filter array support
  - Nicer web gallery exporter -- now touch friendly!
  - OpenCL implementation of VNG/VNG4 demosaicing methods
  - OpenCL implementation of Markesteijn demosaicing method for
    X-Trans sensors
  - Filter-out some useless EXIF tags when exporting, helps keep
    EXIF size under ~64Kb
  - OpenCL: properly discard CPU-based OpenCL devices. Fixes
    crashes on startup with some partially-working OpenCL
    implementations like pocl.
  - darktable-cli: do not even try to open display, we don't need
    it.
  - Hotpixels module: make it actually work for X-Trans
  - Cmstest tool should now produce correct output in more cases,
    especially in multi-monitor setups.
  - Darkroom histogram now uses more bins: use all 8-bit of the
    output, not just 6.
  - Some More Changes, Probably Not Complete:
  - Drop darktable-viewer tool in favor of slideshow view
  - Remove gnome keyring password backend, use libsecret instead
  - When using libsecret to store passwords then put them into
    the correct collection
  - Hint via window manager when import/export is done
  - Quick tagging searches anywhere, not just at the start of
    tags
  - The sidecar XMP schema for history entries is now more
    consistent and less error prone
  - Rawspeed: fixes for building with libjpeg (as opposed to
    libjpeg-turbo)
  - Give the choice of equidistant and proportional feathering
    when using elliptical masks (shift+click)
  - Add geolocation to watermark variables
  - Fix some crashes with missing configured ICC profiles
  - Support greyscale color profiles
  - Lens correction module: switched back to normal Lensfun
    search mode for lens lookups.
  - Make sure that proper signal handlers are still set after GM
    initialization...
  - OSX: add trash support (thanks to Michael Kefeder for initial
    patch)
  - Attach Xmp data to EXR files
  - Several fixes for HighDPI displays
  - Use Pango for text layout, thus supporting RTL languages
  - Feathering size in some mask shapes can be set with
    shift+scroll
  - Many bugs got fixed and some memory leaks plugged
  - The usermanual was updated to reflect the changes in the 2.2
    series
  - Tone curve: mode "automatic in XYZ" mode for "scale chroma"
  - Some compilation fixes
  - Lua specific changes:
  - All asynchronous calls have been rewritten
  - the darktable-specific implementation of yield was removed
  - darktable.control.execute allows to execute some shell
    commands without blocking Lua
  - darktable.control.read allows to wait for a file to be
    readable without blocking Lua
  - darktable.control.sleep allows to pause the Lua execution
    without blocking other Lua threads
  - darktable.gui.libs.metadata_view.register_info allows to add
    new field to the metadata widget in the darkroom view
  - The TextView widget can now be created in Lua, allowing input
    of large chunks of text
  - It is now possible to use a custom widget in the Lua
    preference window to configure a preference
  - It is now possible to set the precision and step on slider
    widgets
  - Changed Dependencies:
  - CMake 3.0 is now required.
  - In order to compile darktable you now need at least
    gcc-4.7+/clang-3.3+, but better use gcc-5.0+
  - Drop support for OS X 10.6
  - Bump required libexiv2 version up to 0.24
  - Bump GTK+ requirement to gtk-3.14. (because even debian
    stable has it)
  - Bump GLib requirement to glib-2.40.
  - Port to OpenJPEG2
  - SDL is no longer needed.
  - Remove gnome keyring password backend
  - Base Support:
  - Canon EOS-1D X Mark II
  - Canon EOS 5D Mark IV
  - Canon EOS 80D
  - Canon EOS 1300D
  - Canon EOS Kiss X80
  - Canon EOS Rebel T6
  - Canon EOS M10
  - Canon PowerShot A720 IS (dng)
  - Canon PowerShot G7 X Mark II
  - Canon PowerShot G9 X
  - Canon PowerShot SD450 (dng)
  - Canon PowerShot SX130 IS (dng)
  - Canon PowerShot SX260 HS (dng)
  - Canon PowerShot SX510 HS (dng)
  - Fujifilm FinePix S100FS
  - Fujifilm X-Pro2
  - Fujifilm X-T2
  - Fujifilm X70
  - Fujifilm XQ2
  - GITUP GIT2 (chdk-a, chdk-b)
  - (most nikon cameras here are just fixes, and they were
    supported before already)
  - Nikon 1 AW1 (12bit-compressed)
  - Nikon 1 J1 (12bit-compressed)
  - Nikon 1 J2 (12bit-compressed)
  - Nikon 1 J3 (12bit-compressed)
  - Nikon 1 J4 (12bit-compressed)
  - Nikon 1 J5 (12bit-compressed, 12bit-uncompressed)
  - Nikon 1 S1 (12bit-compressed)
  - Nikon 1 S2 (12bit-compressed)
  - Nikon 1 V1 (12bit-compressed)
  - Nikon 1 V2 (12bit-compressed)
  - Nikon 1 V3 (12bit-compressed, 12bit-uncompressed)
  - Nikon Coolpix A (14bit-compressed)
  - Nikon Coolpix P330 (12bit-compressed)
  - Nikon Coolpix P340 (12bit-compressed, 12bit-uncompressed)
  - Nikon Coolpix P6000 (12bit-uncompressed)
  - Nikon Coolpix P7000 (12bit-uncompressed)
  - Nikon Coolpix P7100 (12bit-uncompressed)
  - Nikon Coolpix P7700 (12bit-compressed)
  - Nikon Coolpix P7800 (12bit-compressed)
  - Nikon D1 (12bit-uncompressed)
  - Nikon D100 (12bit-compressed, 12bit-uncompressed)
  - Nikon D1H (12bit-compressed, 12bit-uncompressed)
  - Nikon D1X (12bit-compressed, 12bit-uncompressed)
  - Nikon D200 (12bit-compressed, 12bit-uncompressed)
  - Nikon D2H (12bit-compressed, 12bit-uncompressed)
  - Nikon D2Hs (12bit-compressed, 12bit-uncompressed)
  - Nikon D2X (12bit-compressed, 12bit-uncompressed)
  - Nikon D3 (14bit-compressed, 14bit-uncompressed,
    12bit-compressed, 12bit-uncompressed)
  - Nikon D300 (14bit-compressed, 14bit-uncompressed,
    12bit-compressed, 12bit-uncompressed)
  - Nikon D3000 (12bit-compressed)
  - Nikon D300S (14bit-compressed, 14bit-uncompressed,
    12bit-compressed, 12bit-uncompressed)
  - Nikon D3100 (12bit-compressed)
  - Nikon D3200 (12bit-compressed)
  - Nikon D3300 (12bit-compressed, 12bit-uncompressed)
  - Nikon D3400 (12bit-compressed)
  - Nikon D3S (14bit-compressed, 14bit-uncompressed,
    12bit-compressed, 12bit-uncompressed)
  - Nikon D3X (14bit-compressed, 14bit-uncompressed,
    12bit-compressed, 12bit-uncompressed)
  - Nikon D4 (14bit-compressed, 14bit-uncompressed,
    12bit-compressed, 12bit-uncompressed)
  - Nikon D40 (12bit-compressed, 12bit-uncompressed)
  - Nikon D40X (12bit-compressed, 12bit-uncompressed)
  - Nikon D4S (14bit-compressed)
  - Nikon D5 (14bit-compressed, 14bit-uncompressed,
    12bit-compressed, 12bit-uncompressed)
  - Nikon D50 (12bit-compressed)
  - Nikon D500 (14bit-compressed, 12bit-compressed)
  - Nikon D5000 (12bit-compressed, 12bit-uncompressed)
  - Nikon D5100 (14bit-compressed, 14bit-uncompressed)
  - Nikon D5200 (14bit-compressed)
  - Nikon D5300 (12bit-uncompressed, 14bit-compressed,
    14bit-uncompressed)
  - Nikon D5500 (12bit-uncompressed, 14bit-compressed,
    14bit-uncompressed)
  - Nikon D60 (12bit-compressed, 12bit-uncompressed)
  - Nikon D600 (14bit-compressed, 12bit-compressed)
  - Nikon D610 (14bit-compressed, 12bit-compressed)
  - Nikon D70 (12bit-compressed)
  - Nikon D700 (12bit-compressed, 12bit-uncompressed,
    14bit-compressed)
  - Nikon D7000 (14bit-compressed, 12bit-compressed)
  - Nikon D70s (12bit-compressed)
  - Nikon D7100 (14bit-compressed, 12bit-compressed)
  - Nikon D80 (12bit-compressed, 12bit-uncompressed)
  - Nikon D800 (14bit-compressed, 12bit-compressed,
    12bit-uncompressed)
  - Nikon D800E (14bit-compressed, 12bit-compressed,
    12bit-uncompressed)
  - Nikon D90 (12bit-compressed, 12bit-uncompressed)
  - Nikon Df (14bit-compressed, 14bit-uncompressed,
    12bit-compressed, 12bit-uncompressed)
  - Nikon E5400 (12bit-uncompressed)
  - Nikon E5700 (12bit-uncompressed)
  - Olympus PEN-F
  - OnePlus One (dng)
  - Panasonic DMC-FZ150 (1:1, 16:9)
  - Panasonic DMC-FZ18 (16:9, 3:2)
  - Panasonic DMC-FZ300 (4:3)
  - Panasonic DMC-FZ50 (16:9, 3:2)
  - Panasonic DMC-G8 (4:3)
  - Panasonic DMC-G80 (4:3)
  - Panasonic DMC-G81 (4:3)
  - Panasonic DMC-G85 (4:3)
  - Panasonic DMC-GX80 (4:3)
  - Panasonic DMC-GX85 (4:3)
  - Panasonic DMC-LX3 (1:1)
  - Panasonic DMC-LX10 (3:2)
  - Panasonic DMC-LX15 (3:2)
  - Panasonic DMC-LX9 (3:2)
  - Panasonic DMC-TZ100 (3:2)
  - Panasonic DMC-TZ101 (3:2)
  - Panasonic DMC-TZ110 (3:2)
  - Panasonic DMC-ZS110 (3:2)
  - Pentax K-1
  - Pentax K-70
  - Samsung GX20 (dng)
  - Sony DSC-F828
  - Sony DSC-RX100M5
  - Sony DSC-RX10M3
  - Sony DSLR-A380
  - Sony ILCA-68
  - Sony ILCA-99M2
  - Sony ILCE-6300
  - We were unable to bring back these 2 cameras, because we have
    no samples.  If anyone reading this owns such a camera, please
    do consider providing samples.
  - Nikon E8400
  - Nikon E8800
  - White Balance Presets:
  - Canon EOS 1200D
  - Canon EOS Kiss X70
  - Canon EOS Rebel T5
  - Canon EOS 1300D
  - Canon EOS Kiss X80
  - Canon EOS Rebel T6
  - Canon EOS 5D Mark IV
  - Canon EOS 5DS
  - Canon EOS 5DS R
  - Canon EOS 750D
  - Canon EOS Kiss X8i
  - Canon EOS Rebel T6i
  - Canon EOS 760D
  - Canon EOS 8000D
  - Canon EOS Rebel T6s
  - Canon EOS 80D
  - Canon EOS M10
  - Canon EOS-1D X Mark II
  - Canon PowerShot G7 X Mark II
  - Fujifilm X-Pro2
  - Fujifilm X-T2
  - Fujifilm X-T10
  - Fujifilm X100T
  - Fujifilm X20
  - Fujifilm X70
  - Nikon 1 V3
  - Nikon D5500
  - Olympus PEN-F
  - Pentax K-1
  - Pentax K-70
  - Pentax K-S1
  - Pentax K-S2
  - Sony ILCA-68
  - Sony ILCE-6300
  - Noise Profiles:
  - Canon EOS 5DS R
  - Canon EOS 80D
  - Canon PowerShot G15
  - Canon PowerShot S100
  - Canon PowerShot SX100 IS
  - Canon PowerShot SX50 HS
  - Fujifilm X-T10
  - Fujifilm X-T2
  - Fujifilm X100T
  - Fujifilm X20
  - Fujifilm X70
  - Nikon 1 V3
  - Nikon D5
  - Nikon D5500
  - Olympus E-PL6
  - Olympus E-PM2
  - Olympus PEN-F
  - Panasonic DMC-FZ1000
  - Panasonic DMC-GF7
  - Pentax K-1
  - Pentax K-S2
  - Ricoh GR
  - Sony DSLR-A900
  - Sony DSC-RX10
  - Sony ILCE-6300
  - Sony NEX-5
  - Sony SLT-A37
  - New Translations:
  - Hebrew
  - Slovenian
  - Updated Translations:
  - Catalan
  - Czech
  - Danish
  - Dutch
  - French
  - German
  - Hungarian
  - Italian
  - Polish
  - Russian
  - Slovak
  - Spanish
  - Swedish
  - Ukrainian
- add darktable-old-glib.patch to allow building with slightly
  older glib versions
* Fri Oct 28 2016 mrueckert@suse.de
- update to 2.0.7
  - New Features
  - Filter-out some EXIF tags when exporting. Helps keep
    metadata size below max limit of ~64Kb
  - Support the new Canon EOS 80D {m,s}RAW format
  - Always show rendering intent selector in lighttable view
  - Clear elevation when clearing geo data in map view
  - Temperature module, invert module: add SSE vectorization for
    X-Trans
  - Temperature module: add keyboard shortcuts for presets
  - Bugfixes
  - Rawspeed: fixes for building with libjpeg (as opposed to
    libjpeg-turbo)
  - OpenCL: always use blocking memory transfer host<->device
  - OpenCL: remove bogus `static` keyword in extended.cl
  - Fix crash with missing configured display profile
  - Histogram: always show aperture with one digit after dot
  - Show if OpenEXR is supported in `--version`
  - Rawspeed: use a non-deprecated way of getting OSX version
  - Don't show bogus message about local copy when trying to
    delete physically deleted image
  - Base Support (newly added or small fixes)
  - Canon EOS 100D
  - Canon EOS 300D
  - Canon EOS 6D
  - Canon EOS 700D
  - Canon EOS 80D (sRaw1, sRaw2)
  - Canon PowerShot A720 IS (dng)
  - Fujifilm FinePix S100FS
  - Nikon D3400 (12bit-compressed)
  - Panasonic DMC-FZ300 (4:3)
  - Panasonic DMC-G8 (4:3)
  - Panasonic DMC-G80 (4:3)
  - Panasonic DMC-GX80 (4:3)
  - Panasonic DMC-GX85 (4:3)
  - Pentax K-70
  - Base Support (fixes, was broken in 2.0.6, apologies for
    inconvenience)
  - Nikon 1 AW1
  - Nikon 1 J1 (12bit-compressed)
  - Nikon 1 J2 (12bit-compressed)
  - Nikon 1 J3
  - Nikon 1 J4
  - Nikon 1 S1 (12bit-compressed)
  - Nikon 1 S2
  - Nikon 1 V1 (12bit-compressed)
  - Nikon 1 V2
  - Nikon Coolpix A (14bit-compressed)
  - Nikon Coolpix P330 (12bit-compressed)
  - Nikon Coolpix P6000
  - Nikon Coolpix P7000
  - Nikon Coolpix P7100
  - Nikon Coolpix P7700 (12bit-compressed)
  - Nikon Coolpix P7800 (12bit-compressed)
  - Nikon D1
  - Nikon D3 (12bit-compressed, 12bit-uncompressed)
  - Nikon D3000 (12bit-compressed)
  - Nikon D3100
  - Nikon D3200 (12bit-compressed)
  - Nikon D3S (12bit-compressed, 12bit-uncompressed)
  - Nikon D4 (12bit-compressed, 12bit-uncompressed)
  - Nikon D5 (12bit-compressed, 12bit-uncompressed)
  - Nikon D50
  - Nikon D5100
  - Nikon D5200
  - Nikon D600 (12bit-compressed)
  - Nikon D610 (12bit-compressed)
  - Nikon D70
  - Nikon D7000
  - Nikon D70s
  - Nikon D7100 (12bit-compressed)
  - Nikon E5400
  - Nikon E5700 (12bit-uncompressed)
    We were unable to bring back these 4 cameras, because we have
    no samples.  If anyone reading this owns such a camera, please
    do consider providing samples.
  - Nikon E8400
  - Nikon E8800
  - Nikon D3X (12-bit)
  - Nikon Df (12-bit)
  - White Balance Presets
  - Pentax K-70
  - Noise Profiles
  - Sony DSC-RX10
  - Translations Updates
  - Catalan
  - German
* Mon Sep  5 2016 mrueckert@suse.de
- update to 2.0.6
  - New Features
  - Jpeg format writer: use libexiv2 to write metadata, like with
    other formats
  - Accept non-mosaiced raw files with 4 channels, assume they
    are RGBA (alpha channel is ignored)
  - Bugfixes
  - Once again, fix for yet another gtk theming regression...
  - OpenCL: properly discard CPU-based OpenCL devices. Fixes
    crashes on startup with some broken OpenCL implementations
    like pocl.
  - darktable-cli: do not even try to open display, we don't need
    it.
  - Rawspeed: NikonDecoder: stop accepting generic camera
    entries. Fixes multitude of Nikon raw loading issues.
  - OpenCL: fix border handling in crop&rotate module
  - Hotpixels iop: make it actually work for X-Trans
  - Clipping IOP: scale width of gray crop path with zoom level
  - One more fixup to canon lens name reading from exif
  - Fixup Bayer pattern for Olympus SP570UZ
  - Fix internal build issue: do not assume that Perl's @INC
    contains '.'
  - Base Support
  - Canon EOS-1D X Mark II
  - Canon EOS 1300D
  - Canon EOS Kiss X80
  - Canon EOS Rebel T6
  - Canon EOS M10
  - Canon PowerShot G7 X Mark II
  - Canon PowerShot G9 X
  - Fujifilm X-T2
  - GITUP GIT2 action camera
  - Panasonic DMC-FZ18 (16:9, 3:2)
  - Panasonic DMC-FZ50 (16:9, 3:2)
  - Pentax K-1
  - Sony DSLR-A380
  - Sony ILCE-6300
  - Nikon D500
  - Some other whitelevel fixups for some other Nikon cameras (in
    particular, mostly for 12-bit and not compressed raws)
  - White Balance Presets
  - Canon EOS-1D X Mark II
  - Canon EOS 1300D
  - Canon EOS Kiss X80
  - Canon EOS Rebel T6
  - Canon EOS M10
  - Canon PowerShot G7 X Mark II
  - Fujifilm X-T10
  - Sony ILCE-6300
  - Translations Updates
  - Slovak
* Mon Jul  4 2016 mrueckert@suse.de
- update to 2.0.5
  - New Features
  - Add geolocation to watermark variables
  - Bugfixes
  - Mac: bugfix + build fix
  - Lua: fixed dt.collection not working
  - Fix softproofing with some internal profiles
  - Fix non-working libsecret pwstorage backend
  - Fixed a few issues within (rudimentary) lightroom import
  - Some fixes related to handling of duplicates and/or tags
  - Base Support
  - Canon EOS 80D (no mRAW/sRAW support!)
  - White Balance Presets
  - Canon EOS 80D
  - Noise Profiles
  - Canon EOS 80D
  - Translations Updates
  - Danish
  - German
  - Slovak
* Thu May  5 2016 mrueckert@suse.de
- update to 2.0.4
  - New Features
  - Support grayscale input profiles
  - Add a BRG profile for testing purposes
  - Bugfixes
  - Fix the GUI with GTK 3.20
  - Fix the color profiles we ship
  - Fix two deflicker (exposure iop, mode = automatic) issues
  - Fix trashing of files on OSX
  - Fix Rights field in Lua
  - Base Support
  - Nikon D5
  - Sony ILCA-68
  - White Balance Presets
  - Pentax K-S1
  - Sony ILCA-68
  - Noise Profiles
  - Canon PowerShot G15
  - Fujifilm X70
  - Olympus PEN-F
  - Panasonic DMC-GF7
  - Translation Added
  - Slovenian
  - Translations Updates
  - Catalan
  - Dutch
  - German
  - Hebrew
  - Slovak
  - Spanish
* Wed Apr 13 2016 mrueckert@suse.de
- fix version string in darktable ui
* Fri Apr  8 2016 mrueckert@suse.de
- fix conditional for sle12 and leap
* Sun Mar 27 2016 mrueckert@suse.de
- update to 2.0.3
  - Bugfixes
  - Actually allow printing with ctrl-p shortcut as advertised
    in the tooltip
  - Fix scrolling of the histogram to change the exposure
  - Fix the restricted histogram when color picking an area
  - Fix a bug in color reconstruction
  - Fix an OpenCL bug in tonecurve
  - Fix a small memory leak
  - Better error messages in darktable-cli
  - Fix params introspection for unsigned types
  - Only depend on glib 2.32
  - Base Support
  - Fujifilm X70
  - Olympus PEN-F
  - Panasonic DMC-LX3 (1:1)
  - White Balance Presets
  - Canon EOS 1200D
  - Canon EOS Kiss X70
  - Canon EOS Rebel T5
  - Canon EOS 5DS
  - Canon EOS 5DS R
  - Canon EOS 750D
  - Canon EOS Kiss X8i
  - Canon EOS Rebel T6i
  - Canon EOS 760D
  - Canon EOS 8000D
  - Canon EOS Rebel T6s
  - Fujifilm X-Pro2
  - Fujifilm X20
  - Fujifilm X70
  - Olympus PEN-F
  - Noise Profiles
  - Canon EOS 5DS R
  - Fujifilm X20
  - Olympus E-PL6
  - Translation updates
  - Danish
  - German
  - Swedish
* Wed Mar  9 2016 adamm@zombino.com
- updating darktable-old-glib.patch:
  The upstream patch just spins instead of checking the string
  correctly.
* Tue Mar  8 2016 mrueckert@suse.de
- updating darktable-old-glib.patch:
  instead of having a cumbersome if conditional in the spec file
  use the glib_check_version macro in the code
* Sun Mar  6 2016 mrueckert@suse.de
- add darktable-old-glib.patch to fix building on SLE_12
* Sun Mar  6 2016 mrueckert@suse.de
- update to 2.0.2
  - General:
  * Require glib of at least version 2.40
  - New features:
  * Add support for DNGs from x3f_extract
  * Support XMP files from Ramperpro timelapse controllers from
    ElysiaVisuals
  - Bugfixes:
  * Fix some problems with sluggish GUI when Lua is compiled in
  * Some High DPI fixes
  * Small theming fixes
  * Fix some strings being too long in the GUI, especially when
    using localized versions
  * Fix a potential crash with malformed GPX files
  * Fix wrong zoom level of the map when searching for a location
  * Put XMP metadata into the right Exif fields
  * Fix a crash in masks.
  * Fix a crash in demosaicing
  * Fix Markesteijn demosaicing
  * Fix a crash when moving the mouse while going to darkroom
    when crop&rotate is active
  * Fix discrepancy between CPU and OpenCL codepath in invert
  * Fix some crashes with certain TIFF files
  * Fix build with GCC6
  * Fix build with osmgpsmap older than 1.1.0
  * Fix compilation when there are spaces in the path names
  - Camera support:
  * Fujifilm X-Pro2
  - White balance presets:
  * Pentax K-S2
  - Noise profiles:
  * Fujifilm X-T10
  * Pentax K-S2
  - Translations:
  * new:
  * Hebrew
  * updated:
  * German
  * Slovak
  * Swedish
- simplify and merge conditionals with the snapshot packages
* Wed Feb  3 2016 mrueckert@suse.de
- update pdfs to the new 2.0.0 documentation including the
  translated documentation and the lua api documentation.
* Wed Feb  3 2016 mrueckert@suse.de
- update to 2.0.1
  New features:
  * add export variables for Creator, Publisher and Rights from
    metadata
  * add support for key accels for spot removal iop
  * add some more info to --version
  * add collection sorting by group_id to keep grouped images
    together
  * add $(IMAGE.BASENAME) to watermark
  * OSX packaging: add darktable-cltest
  * OSX packaging: add darktable-generate-cache
  Bugfixes:
  * make sure GTK prefers our CSS over system's
  * make selected label's background color visible
  * make ctrl-t completion popup nicer
  * fixed folder list scrolling to the top on select
  * scale waveform histogram to hidpi screens
  * really hide all panels in slideshow
  * add filename to missing white balance message
  * fix wrong tooltip in print scale
  * changing mask no longer invalidates the filmstrip thumb, making
    it faster
  * fix calculated image count in a collection
  * don't allow too small sidepanels
  * fixes white balance sliders for some cameras
  * fix some memleaks
  * code hardening in color reconstruction
  * validate noiseprofiles.json on startup
  * no longer lose old export presets
  * fix some crash with wrong history_end
  * don't load images from cameras with CYGM/RGBE CFA for now
  * some fixes in demosaicing
  * fix red/blue interpolation for XTrans
  * fix profiled denoise on OpenCL
  * use sRGB when output/softproof profile is missing
  * fix loading of .hdr files
  * default to libsecret instead of gnome keyring which is no
    longer supported
  * fix a bug in mask border self intersections
  * don't allow empty strings as mask shape names
  * fix a crash in masks
  * fix an OpenCL crash
  * eliminate deprecated OpenCL compiler options
  * update appdata file to version 0.6
  * allow finding Saxon on Fedora 23
  Camera support:
  * Fujifilm XQ2 RAW support
  * support all Panasonic FZ150 crop modes
  * basic support for Nikon 1 V3
  * add defs for Canon CHDK DNG cameras to make noise profiles work
  White balance presets:
  * add Nikon D5500
  * add Nikon 1 V3
  * add missing Nikon D810 presets
  * add Fuji X100T
  Basecurves:
  * copy X100S to X100T
  Noise profiles:
  * fix typo in D5200 profiles to make them work again
  * add Panasonic FZ1000
  * add Nikon D5500
  * add Ricoh GR
  * add Nikon 1 V3
  * add Canon PowerShot S100
  * copy Fuji X100S to X100T
  Translations:
  * add Hungarian
  * update German
  * update Swedish
  * update Slovak
  * update Spanish
  * update Dutch
  * update French
- remove gnome-keyring buildrequires
* Tue Jan  5 2016 fcrozat@suse.com
- Ensure osm-gps-map support is build for Leap 42.1.
* Tue Dec 22 2015 mrueckert@suse.de
- update to 2.0.0
  when updating from the currently stable 1.6.x series, please bear
  in mind that your edits will be preserved during this process,
  but it will not be possible to downgrade from 2.0 to 1.6.x any
  more.
  Robert Hutton has done a video covering the new features and
  other changes between darktable 1.6 and 2.0:
  https://youtu.be/VJbJ0btlui0
  gui:
  * darktable has been ported to gtk-3.0
  * the viewport in darkroom mode is now dynamically sized, you
    specify the border width
  * side panels now default to a width of 350px in dt 2.0
    instead of 300px in dt 1.6
  * further hidpi enhancements
  * navigating lighttable with arrow keys and space/enter
  * brush size/hardness/opacity have key accels
  * allow adding tone- and basecurve nodes with ctrl-click
  * the facebook login procedure is a little different now
  * image information now supports gps altitude
  features:
  * new print mode
  * reworked screen color management (softproof, gamut check etc.)
  * delete/trash feature
  * pdf export
  * export can upscale
  * new "mode" parameter in the export panel to fine tune
    application of styles upon export
  core improvements:
  * new thumbnail cache replaces mipmap cache (much improved speed,
    stability and seamless support for even up to 4K/5K screens)
  * all thumbnails are now properly fully color-managed
  * it is now possible to generate thumbnails for all images in the
    library using new darktable-generate-cache tool
  * we no longer drop history entries above the selected one when
    leaving darkroom mode or switching images
  * high quality export now downsamples before watermark and
    framing to guarantee consistent results
  * optimizations to loading jpeg's when using libjpeg-turbo with
    its custom features
  * asynchronous camera and printer detection, prevents deadlocks
    in some cases
  * noiseprofiles are in external JSON file now
  * aspect ratios for crop&rotate can be added to config file
  image operations:
  * color reconstruction module
  * magic lantern-style deflicker was added to the exposure module
    (extremely useful for timelapses)
  * text watermarks
  * shadows&highlights: add option for white point adjustment
  * more proper Kelvin temperature, fine-tuning preset
    interpolation in white balance iop
  * monochrome raw demosaicing (for cameras with color filter array
    physically removed)
  * raw black/white point module
  packaging:
  * removed dependency on libraw
  * removed dependency on libsquish (solves patent issues as a side
    effect)
  * unbundled pugixml, osm-gps-map and colord-gtk
  generic:
  * 32-bit support is soft-deprecated due to limited virtual
    address space
  * support for building with gcc earlier than 4.8 is
    soft-deprecated
  * numerous memory leaks were exterminated
  * overall stability enhancements
  scripting:
  * lua scripts can now add UI elements to the lighttable view
    (buttons, sliders etc...)
  * a new repository for external lua scripts was started:
    https://github.com/darktable-org/lua-scripts
  * it is now possible to edit the collection filters via lua
  * it is now possible to add new cropping guides via lua
  * it is now possible to run background tasks in lua
  * a lua event is generated when the mouse under the cursor
    changes
  Usermanual has been updated, and will be released shortly after.
  New camera support, compared to 1.6.9:
  Base Support
  - Canon PowerShot G5 X
  - Olympus SP320
  - Panasonic DMC-FZ150 (3:2)
  - Panasonic DMC-FZ70 (1:1, 3:2, 16:9)
  - Panasonic DMC-FZ72 (1:1, 3:2, 16:9)
  - Panasonic DMC-GF7 (1:1, 3:2, 16:9)
  - Panasonic DMC-GX8 (4:3)
  - Panasonic DMC-LF1 (3:2, 16:9, 1:1)
  - Sony DSC-RX10M2
  White Balance Presets
  - Canon EOS M3
  - Canon EOS-1D Mark III
  - Canon EOS-1Ds Mark III
  - Canon PowerShot G1 X
  - Canon PowerShot G1 X Mark II
  - Canon PowerShot G15
  - Canon PowerShot G16
  - Canon PowerShot G3 X
  - Canon PowerShot G5 X
  - Canon PowerShot S110
  - Panasonic DMC-GX8
  - Panasonic DMC-LF1
  - Pentax *ist DL2
  - Sony DSC-RX1
  - Sony DSC-RX10M2
  - Sony DSC-RX1R
  - Sony DSLR-A500
  - Sony DSLR-A580
  - Sony ILCE-3000
  - Sony ILCE-5000
  - Sony ILCE-5100
  - Sony ILCE-6000
  - Sony ILCE-7S
  - Sony ILCE-7SM2
  - Sony NEX-3N
  - Sony NEX-5T
  - Sony NEX-F3
  - Sony SLT-A33
  - Sony SLT-A35
  Noise Profiles
  - Canon EOS M3
  - Fujifilm X-E1
  - Fujifilm X30
  - Nikon Coolpix P7700
  - Olympus E-M10 Mark II
  - Olympus E-M5 Mark II
  - Olympus E-PL3
  - Panasonic DMC-GX8
  - Panasonic DMC-LF1
  - Pentax K-50
  - Sony DSC-RX1
  - Sony DSC-RX10M2
  - Sony ILCA-77M2
  - Sony ILCE-7M2
  - Sony ILCE-7RM2
  - Sony SLT-A58
* Tue Nov 17 2015 mrueckert@suse.de
- s/pkg-config/pkgconfig/ for fedora
* Tue Nov 17 2015 mrueckert@suse.de
- add fedora 23 support to conditionals
- enable osm gps map support for fedora >= 22
- extract the cmake options into a define
* Fri Nov 13 2015 mrueckert@suse.de
- first steps to build also on fedora
* Tue Nov  3 2015 mrueckert@suse.de
- restore some cmake flags to make the package more compatible with
  CPUs
* Tue Nov  3 2015 mrueckert@suse.de
- make more BR conditional to enable building on more distros
* Sun Nov  1 2015 mrueckert@suse.de
- do not strip the rpath, DT actually needs it.
* Sun Nov  1 2015 mrueckert@suse.de
- update to 2.0~rc1
  when updating from the currently stable 1.6.x series, please bear
  in mind that your edits will be preserved during this process,
  but it will not be possible to downgrade from 2.0 to 1.6.x any
  more. be careful if you need darktable for production work!
  - darktable has been ported to gtk-3.0
  - new thumbnail cache replaces mipmap cache (much improved speed,
    less crashiness)
  - added print mode
  - reworked screen color management (softproof, gamut check etc.)
  - text watermarks
  - color reconstruction module
  - raw black/white point module
  - delete/trash feature
  - addition to shadows&highlights
  - more proper Kelvin temperature, fine-tuning preset
    interpolation in WB iop
  - noiseprofiles are in external JSON file now
  - monochrome raw demosaicing (not sure whether it will stay for
    release, like Deflicker, but hopefully it will stay)
  - aspect ratios for crop&rotate can be added to conf (ae36f03)
  - navigating lighttable with arrow keys and space/enter
  - pdf export -- some changes might happen there still
  - brush size/hardness/opacity have key accels
  - the facebook login procedure is a little different now
  - export can upscale
  - we no longer drop history entries above the selected one when
    leaving dr or switching images
  - text/font/color in watermarks
  - image information now supports gps altitude
  - allow adding tone- and basecurve nodes with ctrl-click
  - we renamed mipmaps to thumbnails in the preferences
  - new "mode" parameter in the export panel
  - high quality export now downsamples before watermark and frame
    to guarantee consistent results
  - lua scripts can now add UI elements to the lighttable view
    (buttons, sliders etc...)
  - a new repository for external lua scripts was started.
- drop generate generate-tarball.sh as it is no longer needed
- use cmake macros
- start buildrequires list from scratch
* Wed Oct 21 2015 mrueckert@suse.de
- update to 1.6.9
  - general:
  - don't build with external lua 5.3 or higher (darktable MUST
    be built with lua 5.2)
  - format datetime locale dependant (and try to handle timezones
    better)
  - fix various minor memory leaks
  - use sRGB as display profile on all versions of OS X, fixes
    monitor profile being applied twice
  - rawspeed (newly added camera support should be considered
    experimental for the time being):
  - olympus e-m10 mk2
  - canon g3 x
  - canon powershot sx60hs
  - sony a7r ii
  - fuji x-a2
  - panasonic fz1000 bad pixel detection
  - alias panasonic tz70/zs50 to the tz71
  - improve samsung nx1/nx500 support (handle 12bit modes)
  - don't load broken kodak kdc files
  - wb_presets:
  - olympus e-m10 mk2
  - canon powershot sx60hs
  - canon powershot g7 x
  - sony a7r ii
  - sony a7 ii
  - sony rx100m4
  - sony rx10
  - nikon 1 j5
  - noiseprofiles:
  - nikon d3300
  - canon powershot s120
  - translations:
  - swedish (small updates)
* Wed Sep 16 2015 fcrozat@suse.com
- Adapt BuildRequires for build on openSUSE Leap 42.1.
* Thu Jul 30 2015 mrueckert@suse.de
- update to 1.6.8
  - miscellaneous
  - clipping, santiy check for custom aspect ratios
  - read lensmodel from xmp
  - handle canon lens recognition special case
  - general cleanups
  - rawspeed:
  - Canon EOS M3
  - Canon EOS 5Ds (R)
  - Nikon 1 J5
  - Panasonic DMC-G7 (4:3 aspect ratio only)
  - Fujifilm X-T10
  - Pentax K-S2
  - Panasonic TZ71
  - Olympus TG-4
  - Leica VLUX1 4:3 aspect ratio mode
  - adobe_coeff:
  - Canon EOS M3
  - Canon EOS 5Ds (R)
  - Nikon 1 J5
  - Panasonic DMC-G7
  - Fujifilm X-T10
  - Pentax K-S2
  - Olympus TG-4
  - wb_presets:
  - Samsung NX500
  - Panasonic TZ71
  - noise profiles:
  - Sony ILCE-5100
  - Fujifilm HS50EXR
  - Canon EOS 5Ds R
- do not try to use lua 5.3 on TW
* Tue Jun 30 2015 mrueckert@suse.de
- Update to version 1.6.7 (boo #930683)
  - security
  - libraw CVE-2015-3885: fix integer overflow in ljpeg_start()
  - miscellaneous
  - improvements to facebook export
  - interpolation fixups
  - demosaic code cleanups
  - slideshow should handle very small images better
  - improve Olympus lens detection
  - various minor memory leak fixes
  - various other fixes
  - Pentax (K-x) DNG old embedded preview left over is now
    removed
  - modern OSX display profile handling
  - camera support
  - Nikon D7200 (both 12bit and 14bit compressed NEFs)
  - Nikon Coolpix P340
  - Canon EOS 750D
  - Canon EOS 760D
  - Canon EOS M2
  - Panasonic DMC-CM1
  - Panasonic DMC-GF7 (4:3 only)
  - Olympus XZ-10
  - Olympus SP570UZ
  - Samsung NX500
  - Fuji F600EXR
  - aspect ratios
  - Pansonic DMC-G5
  - Panasonic DMC-GM5
  - Panasonic FZ200
  - white balance presets
  - Nikon D7200
  - Nikon Coolpix P340
  - Panasonic DMC-GM1
  - Panasonic DMC-GM5
  - Olympus E-M10 (updated)
  - Olympus E-PL7
  - Olympus XZ-10
  - noise profiles
  - Canon Powershot G9
  - Sony A350
  - basecurves
  - Nikon D7200
  - Nikon D7000
  - Nikon D750
  - Nikon D90
  - translations updates: Catalan German Spanish Swedish
* Sat Apr 25 2015 mrueckert@suse.de
- Update to version 1.6.6
  - fix the Olympus E330 support (which was accidentally broken in
    1.6.4)
  - fix white balance reading for the Canon Powershot SX50 HS
  - white balance presets for RICOH GR
  - minor assorted bug fixes (masks, lens correction, profiled
    denoise, etc)
- remove unused cmake option from the cmdline:
  INSTALL_IOP_EXPERIMENTAL
* Fri Apr 17 2015 mrueckert@suse.de
- Update to version 1.6.4
  - general improvements:
  - major rawspeed update
  - facebook exporter update (first authentication usability
    should be much better now)
  - first run opencl benchmark to prevent opencl autoactivation
    if gpu is obviously slower than cpu
  - lensfun cornercase fixes
  - some mask cornercase fixes
  - zonesystem now updates it's gui when number of zones changes
  - spots iop updates
  - ui_last/gui_language should work more reliably now
  - internal lua updated from 5.2.3 to 5.2.4 (distro's typically
    use their own version of lua)
  - gcc 5 should build now
  - new camera support:
  - canon digital rebel (non european 300d)
  - nikon d5500 (experimental)
  - olympus e-m5 mark ii (experimental)
  - Samsung NX500 (experimental)
  - white balance presets:
  - sony a77 ii
  - fujiflim x-e2
  - olympus e-m5 mark ii
  - noise profiles:
  - canon 7d mark ii
  - updated translations: german french russian danish catalan
    japanese dutch
- drop 826152bc3564e74133680cc53e69e040d3663b47.patch included in
  release
* Mon Mar 23 2015 mrueckert@suse.de
- added 826152bc3564e74133680cc53e69e040d3663b47.patch:
  Backport from upstream to fix upstream issue #10370
  'Unable to work with Canon EOS Rebel images using darktable 1.6'
* Mon Mar  2 2015 toganm@opensuse.org
- Update to version 1.6.3
  * Changes:
    + Make camera import window transient
    + Allow soft limits on radius
    + Fix soft boundaries for black in exposure
    + Change order of the profile/intent combo in export dialog
    + Support read/write of chromaticities in EXR
    + Allow to default to :memory: db in config
    + Add mime handler for non-raw image file formats
    + Improved lens model name detection for Sony SAL lenses
  * Bug fixes:
    + Fix buffer overrun in SSE clipping loop for highlight handling
    + Prevent exporting when an invalid export/storage is selected
    + Hopefully last fix for aspect ratios in crop and rotate (#9942)
    + No tooltip when dragging in monochrome (#10319)
  * RAW support:
    + Panasonic LX100 (missing non-standard aspect ratio modes)
    + Panasonic TZ60
    + Panasonic FZ1000
    + KODAK EASYSHARE Z1015 IS
    + Canon 1DX (missing sRAW modes)
    + Canon A630 and SX110IS (CHDK RAW)
  * white balance presets
    + Panasonic FZ1000
    + Panasonic TZ60
    + Panasonic LX100
  * standard matrix
    + Canon Rebel T3 (non-european 1100D)
  * enhanced matrix
    + Nikon d750
  * noise profiles:
    + Canon EOS 1DX
* Sun Feb  1 2015 toganm@opensuse.org
- Update version 1.6.2
  * General improvements:
    + Better names for key accels (no more <Primary>)
    + Local gallery export limited to useful web formats
    (JPEG/PNG/WebP)
    + Add a way to control the brush size with keys
    + Default X-Trans Demosaic to markesteijn (single pass)
  * Bugfixes:
    + Fix IPTC Keyword reading for real
    + rawspeed: support short values in DNG ActiveArea
    + really disable parallel export
    + remove special characters from style export
    + Cropping aspect ratio fixes (#9942, #10265)
    + Some fixes to lua/masks/brushes
  * Camera support:
    + Pentax *ist DS
    + Pentax *ist DL2
    + Pentax K110D
    + Sony A7 II
    + Sony ILCE-3500
    + Nikon 1 S2
    + Olympus E-450
    + Panasonic LX1
    + Panasonic G3 (aspect ratio modes)
    + Samsung NX1 blackpoint finetuning
    + Fuji X-E1 blackpoint finetuning
  * White balance presets
    + 7D Mark II (updated)
    + Olympus E-M1
    + Sony A99
* Sat Jan 10 2015 toganm@opensuse.org
- Update to version 1.6.1
  * this is a point release which fixes a couple of minor issues in
    the recent feature release 1.6.0 (such as a crash with images
    greater than 134 megapixels).
* Mon Dec  8 2014 toganm@opensuse.org
- Update to version 1.6.0
  * general/misc:
    + high DPI monitor support
    + map view now allows to only show images from the current
    collection on the map
    + slideshow
    + darktable-cli now works without a running X server for use on
    headless systems
    + support for audio notes playback
    + sticky preview
    +  added the option to overwrite files when exporting to disk
    + crawler that syncs all xmp files on start
    + support huge images (> 32 bit pixel index). darktable can open
    26770x13385 TIFFs and should in theory be able to process arbitrary
    sized images. don't try this on a 32 bit system though!
    + lens iop presets are copy/pastable between different images
  * output
    + tiff read/write rewritten, works on 32-bit float now, supports
    compression
    + allow setting PPI for exported JPEGs, defaulting to 300
    pwstorage libsecret
    + use HTTPS when exporting to flickr
  * colour
    + color conversion speedup (openmp for lcms2 case)
    + add linear Rec2020 as a build-in profile
    + embedded icc profile support for png/tiff (read/write)
  * lua scripting:
    + copy, move, reset and delete images via lua
    + handle progress bars via lua
    + limited manipulation of libs an views UI via lua
    + import and export styles via lua
    + trigger lua when the grouping mode changes
    + trigger lua when the overlay mode changes
    + trigger lua when the active view changes
    + manipulate snapshots via lua
    + handle more types of preferences, including enums, directories
    and file names  lua API is now versioned: use
    darktable.configuration.check_version to check
    + lua API incompatibilities: darktable.modules has been removed,
    use darktable.new_format and darktable.new_storage to access the
    constructors
  * performance improvements
    + many speed improvements by adding sse code for image operations
    + make white balance work faster
    + make invert work faster
    + much faster exr export with optional compression (multicore
    support)
    + speedup of pfm writing
    + speedup of amaze. it is still slow but not as bad as it used to
    be
  * internal improvements:
    + module parameter introspection
    + clang/address-sanitizer/etc compiler warnings fixed
    + flip iop used for raw auto-orientation (simplifies code)
    + complete rawspeed migration for raw loading
  * bug fixes:
    + hdr bracketing fixes
    + masks cleanup and bugfixes
    + correct lens detection for compact cameras
    + avoid clipping in vignette, lowpass, shadows & highlights, a/b
    channels of colorcontrast and tonecurve
  * updated usermanual
  * lots of small performance improvements and code cleanup
  * Change source locations to reflect github project
* Wed Sep 17 2014 toganm@opensuse.org
- Add generate-tarball.sh as source file
* Tue Sep 16 2014 dmitry_r@opensuse.org
- Fix GraphicsMagick build dependencies
* Sat Apr 26 2014 fcrozat@suse.com
- update to version 1.4.2:
  + masks fixes
  + Explicitly try to load live view frames as JPEG
  + Silence calculator error messages
  + Translations updates
  + Aspect ratio modes for Panasonic DMC-G2
  + WB presets for Olympus E-PL5/E-PM2, Nikon D610, D3300
  + Various TIF fixes
  + Fix potential format string attacks via .po files
  + Add $(TITLE) to export variables
  + opencl: fix border handling in lens correction module
  + Experimental support and matrix for samsung nx30, nx1100,
    Olympus E-M10, Canon 1200d, Nikon D3300, D5300
  + Fix memory bugs spotted by Coverity
  + Various crash fixes
  + Update amaze code (SSE2 code)
  + Set lt position when changing image in dr with keys
  + Tonecurve: fix serious logical flaw.
  + Colorout: map shortkeys of gamut check/softproof to
    ctrl-g/ctrl-s
  + Fix crash when exporting to Picasa.
  + Noise profile: panasonic dmc-lx7
  + TIFF output: several fixes
  + Fix for Olympus focus distances
  + Tonecurve revamped
  + Try to limit network traffic of map view
* Sun Feb  9 2014 toganm@opensuse.org
- update to version 1.4.1
  * export: consistent names for output formats
  * export to disk: overwrite file option
  * grain plugin now allows smaller coarseness and will display
    coarseness values half of what they used to be, this is merely a
    cosmetic change, your images are unaffected.
  * some masks related fixes
  * some lua related fixes
  * tiff writer (32bit float, little endian output, configurable
    compression)
  * tiff reader
  * subtly nicer scrollbar behavior
  * theme loading cornercase fixups
  * shadow & highlight module improvements (should be less prone to
    artifacts when used on new images)
  * allow importing more than 1 style at a time
  * regression was fixed when building darktable against bleeding
    edge glibc
  * Sony A77V enhanced color matrix
  * Nikon D5100 updated white balance presets
  * Nikon 1 V2 noise profile (and by extension J3/AW1)
  * Nikon 1 J1 noise profile (and by extension V1/J2/S1)
  * Pentax K3 noise profile
  * experimental support for Panasonic DMC-LF1 (we still need
    samples for the nonstandard aspect ratios)
  * experimental support for SONY DSC-RX100M2
  * experimental support for SONY NEX-3N
  * still no Nikon D5300/D3300 support, we're still looking into
    that.
- Added pkgconfig(xandr) to build requires
* Wed Jan  1 2014 adrian@suse.de
- update to final version 1.4
- removed patches:
  * 0001-Fix-9720-Don-t-crash-when-kwallet-is-not-running.patch
* Mon Dec 16 2013 toganm@opensuse.org
- Fixes #bnc855442
  * added patches:
  - 0001-Fix-9720-Don-t-crash-when-kwallet-is-not-running.patch
* Sun Dec  1 2013 toganm@opensuse.org
- Update to release candidate 1.4~rc1
  * darktable now integrates a lua engine that allows writing scripts
    to make it easier to use with other image processing software.
    These scripts can be run when a particular event takes place (for
    example when a new image is imported) or when a particular keyboard
    shortcut is used. There are very few scripts available at this
    point but we expect the community to provide some more during the
    next release cycle.
  * darktable now include several kinds of drawn masks: brush,
    circle, ellipse, path and gradients
  * exporting in WebP format
  * serious speed enhancements of lighttable when using large
    colections
  * focus detection on lighttable
  * local cached copies of images for offline files
  * a few new blend mode like "HSV lightness", "HSV color", "Lab
    lightness" and "Lab color"
  * new modules "contrast brightness saturation", "color balance" and
    "color mapping" which replaces the now deprecated "color
    transfer" module
  * new histogram mode "waveform"
  * added a setting to automatically collapse modules to only have a
    single one expanded
  * better user experience for bauhaus sliders: the popup now has a
    blinking cursor to make possible text entry more discoverable
  * the text entry for bauhaus sliders and vimkeys' ":set" command
    can now evaluate mathematical expressions
  * many bug fixes and small improvements
  * a tool for measuring basecurves from a sample image
- Remove backported
  0001-Allow-compilation-with-colord-and-without-squish.patch
* Sun Nov 24 2013 toganm@opensuse.org
- Backported patch for colord compilation without squish
  0001-Allow-compilation-with-colord-and-without-squish.patch
* Tue Sep 10 2013 toganm@opensuse.org
- Update to version 1.2.3
  + Update to RawSpeed r570
  + Canon 70D (preliminary)
  + Olympus E-P5 (incl. preliminary Adobe Coeff.)
  + Samsung NX2000
  + Sony RX100m2
  + Sony SLT-A58 (updated)
  * White Balance Presets:
  + Sony NEX-5R
  + Sony SLT-A58
  + Nikon D3200 (updated)
  + Pentax K20D
  * Enhanced Color Matrix:
  + Pentax K20D
  * Noise Profiles:
  + Canon EOS 1100D == Canon EOS Rebel T3
  + Canon PowerShot S95
  + Canon PowerShot G11
  + Nikon Coolpix P330
  + Sony A580
  + Fuji X10
  + Pentax K20D
  * Fixes and improvements:
  + Increased maximum cache size to 8GB
  + OS X: fix Facebook uploads
  + Adjustments to default lowpass blur settings
  + Adjustments to dithering slider ranges
  + Metadata viewer: fix display of focal length: indicate unit
    and hide  if invalid.
  + Chromatic Aberrations: fix segfault for small buffers
  + Color pickers: fix various issues, e.g. #9482
  + More guides for Crop & Rotate
  + Improve light table usability: when viewing images in
    fullscreen wrap  around at line end when pressing right arrow
    key
  + Soften: massive speed improvements by using SSE and OpenMP
  + Deleting images from camera is not supported anymore for
    safety.
  + Exposure module now supports multiple instances
  + Support for custom meta data burn in (see commit
    6ac7ba055440aa27f79f0a67ac112799a0e7785e)
  + OpenCL support for nVidia GeForce GT330
  + PFM: load timestamp as date & time taken.
  + Fix bug prohibiting image rating by mouse
  + Update Picasa uploader: references Google+ now
  + Some fixes for memory leaks, deadlocks, background jobs
  + Fixes of on-screen handles for Crop&Rotate and GND modules
  + 0 bytes files will no longer be imported but ignored
* Tue Jun 25 2013 toganm@opensuse.org
- Update to version 1.2.2
  * updated rawspeed r553. Support for
    + Canon EOS 700D
    + Nikon Coolpix P330
  * New Olymbus base curve
  * Updated Adobe Coeffs
  * Enhanced color matrices:
    + Canon 700D (from Canon 650D)
    + Canon 100D (from Canon 650D)
  * Sony NEX-7
  * White balance presets:
    + Some updates from UFRaw
    + Canon 100D
    + Canon 700D
    + Sony SLT-A37
    + Nikon Coolpix P330
  * Noise profiles:
    + Canon EOS-M
    + Olympus E-600 (from: Olympus E-30)
    + Olympus E-620 (from: Olympus E-30)
    + Samsung WB2000
    + Sony A99v
    + Panasonic DMC-G10 iso 100
    + Nikon D60
  * Bug fixes:
    + 0 star rating working again
    + LT: ctrl+d duplicates per default now
    + Some fixes concerning locale handling
    + double click on film strip jumps to image
    + remember position in collections
    + ctrl+k jumps to previous collection
    + Blending parameters are preserved when module is deactivated
    + In full-preview (alt-1) ratings and labels are only applied to
    + image shown
    + Various OpenCL fixes, e.g. compilation on Mac OS X
    + libsquish compilation now optional
    + dr: deactivate interpolation at 200%% zoom
  * Removed backported patches:
  0001-thumbnail-compression-make-libsquish-optional
  0001-fixed-error-handling-for-broken-full-color-images.patch
* Thu Jun 20 2013 toganm@opensuse.org
-  Remove patented code from the source via
  generate--tarball.sh bnc#824484
  * added backported patch from git master
    0001-thumbnail-compression-make-libsquish-optional
  * Remove pkgconfig(colord) from Build Requires
  Because compression code is disabled previous cache will not
  work. Removing  ~/.cache/darktable/mipmaps is necessary
* Mon Jun 10 2013 toganm@opensuse.org
- added backported patch from git master
  0001-fixed-error-handling-for-broken-full-color-images.patch
  fixes bnc#823114
* Sun May 26 2013 toganm@opensuse.org
- Update to release 1.2.1
  * New translation: Danish
  * Some translations have been removed from the release due to
    missing strings
  * New noise profiles
    + Canon EOS 450D / Kiss X2
    + Canon EOS 1100D / REBEL T3
    + Canon EOS 1D Mark II
    + Canon EOS 1D Mark III
    + All Canon Model names are now recognized, e.g. Canon EOS 350D
    and Canon EOS 350D DIGITAL and Canon EOS DIGITAL REBEL XT and
    Canon EOS Kiss Digital N point to the same camera.
    + Olympus E-520
    + Olympus E-1
    + Olympus E-3
    + Olympus E-P2
    + Pentax K-30
    + Panasonic GH-2
    + Panasonic DMZ-FZ18
    + Additional data for Pentax K-5 II
    + Nikon D7100
    + Nikon D5200
    + Sony A57
  * White balances, color matrices
    + Fix issues with different camera model names for various Canon
    cameras (see above)
    + White balance for Panasonic DMC-GH2
    + Updates whitebalance list with the latest version of UFRaw's cvs version
    + Whitebalances for Samsung NX5, NX10, NX11 (copied from NX100)
  * Bugfixes
    + new RawSpeed version r537
    + Compatible with openEXR 2.0
    + Facebook export now allows HQ images (up to 2048px)
    + Blend mode "vividlight" should work for NaNs
    + Fix compile issues for OpenBSD
    + Whitebalance is now relative to daylight, not to camera white
    balance (this will not change any processing you have done,
    only the values displayed will differ)
    + Now importing folder via key accelerator is supported.
    + Only one temperature slider in white balance
    + Some fixes to the zoom behaviour in darkroom mode
    + New lensfun geometries now supported (with lensfun >= 0.2.7)
    + More coherent bauhaus UI for the split toning module
    + The color transfer module is now marked as deprecated. Will be
    superseeded by color mapping in the next major release.
    + Fix some possible deadlocks, memory leaks and null pointer dereferences
    + Status message in top bar should be updated more frequently now
    + Some more elaborate status messages if lens/camera not found in the
    lens correction module, if export failed
    + Option for parallel export threads removed from config, too dangerous
    + Option for thumbnail cache now specified in MB
    + Updated purge_non_existing_images.sh script
    + CLI option -d nan gives per-module output of NaN values
    + Some minor renamings, typo fixings...
- Drop 0001--OpenEXR-2.0-fixes.patch since fixed upstream
* Fri Apr 26 2013 mrueckert@suse.de
- First set CFLAGS and then CXXFLAGS. Sometimes we need to set
  flags in CXXFLAGS that are not valid CFLAGS.
* Tue Apr 23 2013 toganm@opensuse.org
- Fix factory build with OpenEXR-2.0
  added 0001-OpenEXR-2.0-fixes.patch
* Sat Apr  6 2013 toganm@opensuse.org
- Update to release 1.2
- removed
  darktable-1.2.x_update_to_4b856e6ec99035d5a1041db73e2339000d395aa0.patch
  as it is now included.
- When possible use pkgconfig hence:
  instead of libopenjgeg-devel  used  pkgconfig(libopenjpeg)
  instead of GraphicsMagick-devel used pkgconfig(GraphicsMagick)
- If build is for 12.1 then require gtk2-engines
* Thu Apr  4 2013 mrueckert@suse.de
- added darktable-1.2.x_update_to_4b856e6ec99035d5a1041db73e2339000d395aa0.patch:
  update to HEAD (4b856e6ec99035d5a1041db73e2339000d395aa0)
  - adobe_coeff: Nikon Coolpix A same as D7000
  - fix-crash-lr-import:
    Proactive fix to avoid a crash trying to dereference a null
    pointer.  If node stEvt:softwareAgent not found, skip as not a
    lightroom xmp.
  - don't crash on malformatted TIFF file
    In case a file was alraedy rejected by GraphicsMagick, it's not
    a good idea to try open it with our handmade imageio routines
    like TIFFOpen().  Let's take GraphicsMagick as a last resort if
    available.
  - usermanual: add missing file lighttable_directory.png
  - Fix: snapshot + gnd, cliping, ... #9329
  - Upgraded and reviewed Spanish translation
    I have fully reviewed the Spanish translation, fixing typos,
    improving grammar and the language used.
  - denoiseprofile: really fix legacy_params
  - denoiseprofile: get param "mode" right when converting params
    from version 2 to 3 fix: denoiseprofile: crash when trying to
    update presets/styles from version 2 to 3 do not try to find
    autodetection for them - would probably be not useful and is
    impossible anyway
  - Merge pull request #206 from bluesceada/denoise-copy-autodetect
    denoiseprofile: copy "profile autodetected" correctly + fix:
    display "found match" also for first profile
  - noise profile: canon eos 1d iv by rene weiss
  - denoiseprofile: only use a[0] = -1.0 to signal autodetection,
    and don't use epsilon for comparisons
  - denoiseprofile: make it possible to copy the information "this
    profile was set automatically" across images with different ISO
    and camera vendor
  - fix: denoiseprofile: also show "found match:" instead of the
    profile name for index 0
  - Preliminary update of the Russian translation
  - Merge branch 'fix-clipping-aspect'
  * fix-clipping-aspect:
    Fix aspect ratio computation.
    It cannot happen in legacy_params() as at this point the size
    of the image is not yet known. We then use a deferred
    circuitry to handle this at the right point in the code.
    Fixes #9320.
  - [l10n] Swedish update
* Thu Apr  4 2013 mrueckert@suse.de
- update to release 1.2.rc2
  - the changes on top of rc1 are minor, some details:
  - fixed a spurious crash/deadlock when switching images in
    filmstrip mode
  - fixed a couple of exif strings for profiled denoising
  - fixed gcc 4.8.0 build
  - new noise profiles
  - fixed gphoto 2.5 issues
  - updated translations
  - updated user manual!
- additional changes from 1.2.rc1
  - profiled denoising: adapt to the properties of your camera's
    sensor (72 cameras already profiled for you).
  - lightroom import: convert some basic edits from your lightroom
    collection to darktable operations.
  - multi instance support: duplicate your modules and apply them
    more than one time with different settings.
  - improved usability for distorting modules (streamline spot
    removal in the presence of crop/rotate for example).
  - selective copy/paste of image processing.
  - new more intuitive keystone correction tool.
  - jpeg2000 support.
  - graphics magick import (support virtually all input image
    formats).
  - much faster thumbnail loading (if you can live with crappy
    embedded thumbnails).
  - incredibly lengthy list of small bug fixes, performance
    enhancements, and usability improvements.
  - new camera support (decode and color matrices).
  - dithering against banding.
  - sharper thumbnails in lighttable mode.
  - new oauth2 based picasa uploader.
  - and the final release 1.2 will contain a thoroughly overhauled
    user manual, proof read by natives (thanks heaps guys!).
- removed 0001-Fix-svg-uses-premultiplied-alpha-we-didn-t-respect-t.patch
  included upstream
- added BuildRequires for GraphicsMagick and openjpeg
* Sun Mar 17 2013 fcrozat@suse.com
- Add gtk2-engine-clearlooks as Requires, needed for darktable
  black theme.
* Sun Mar 10 2013 toganm@opensuse.org
- Update to release 1.1.4 This is bugfix release no new features
  are introduced.
  * Fix tooltip style definition in darktable.gtkrc.
  * colorspaces: avoid trademark issues
  * colorspaces: workaround horrible brokenness of some printshops
  * colorspaces: actually cprt is a required icc tag
  * thumbs: use mip always > image size, not closest.
  * wb_presets: Nikon D3200 (stolen from UFRaw)
  * wb_presets: SONY SLT-A77V
  * wb_presets: Panasonic DMC-G5 (thanks to thouks)
  * wb_presets: Pentax K-5 II s (thanks to Jack Bowling)
  * wb_presets: Nikon D800(E) update
  * rawspeed: minor fix for LX7 in 3:2 mode
  * rawspeed: support Panasonic DMC-LX7 16:9 and 1:1 aspect ratio modes
  * rawspeed: support Panasonic DMC-LX7 3:2 aspect ratio mode
  * rawspeed: Preliminary support for the PENTAX K-5 II s
  * rawspeed: added Panasonic DMC-G5 1:1/16:9 modes
  * rawspeed: Nikon 1 S1 support
  * rawspeed: Nikon 1 J3 support
  * rawspeed: Nikon Coolpix P7100 blackpoint fix (thanks to nesthib)
  * Fix base curve presets for Canon on Spanish locale
  * Fix #9205: Read metadata from non-dt XMPs
  * blend: fix edge case in color blend mode
  * redraw: remove now obsolete flood stopping.
  * redraw: allow more redraws per second.
  * redraw signal: simplify the locking logic somewhat.
  * pack blendif settings a little bit closer in GUI
  * cache: have full buffers according to potentially exporting  threads
  * lens correction: fix for #9270
  * opencl: work around a bug in some OpenCL drivers
  * exif: return correct buffer length, patch by wolfgang goetz
  * match leica basecurve less selectively
  * Olympus E-M5 enhanced matrix with help from Frederic Crozat
  * ICC profile handling: catch certain mal-formatted profiles
- Added 0001-Fix-svg-uses-premultiplied-alpha-we-didn-t-respect-t.patch
- Remove 0001-Olympus-E-M5-enhanced-matrix.patch as it's upstreamed
* Sun Feb 10 2013 fcrozat@suse.com
- Add 0001-Olympus-E-M5-enhanced-matrix.patch: Enhanced matrix for
  Olympus OM-D E-M5.
* Sat Feb  9 2013 toganm@opensuse.org
- Update to release 1.13
  * fixes:
    + check (on build) if glib 2.28 or higher is present
    + don't sanatize exif when creating hdr dngs
    + colorpicker now disappears immediately when disabling it
    + lens correction now uses loose lens matching (ivan tarozzi)
    + konica minolta dynax 5d rotation fix
    + removed an outdated assertion which could cause a crash in rare
    cases
    + don't crash when loading half-corrupted xmp's
    + don't crash when an imported file contains incomplete gps
    information
    + libjpeg-turbo workaround (klaus post)
  * camera support:
    + preliminary support for the new nikon d5200
  * white balance presets:
    + sony alpha 700 (update to firmware v4)
    + sony alpha 230 (new)
    + canon eos 650d (new)
    + canon eos rebel t2i (fixed)
    + canon eos m (fixed)
  * enhanced color rendition:
    + konica minolta dynax 5d (wolfgang kuehnel)
    + sony nex 3 (wolfgang kuehnel)
    + sony alpha 230 (wolfgang kuehnel)
    + sony rx100 (josef wells)
- For openSUSE 12.1 added xz to buildrequires
* Sun Jan 13 2013 toganm@opensuse.org
- Update to release 1.1.2
  * darktable 1.1.2 is mostly a camera support update and bugfix
    release:
  - fix export resolution rounding issue (as in previous version it
    could be off-by-one)
  - correctly set output dimension in exif instead of passing the raw
    resolution verbatim
  - local average green eq was fixed (it now works on high iso images
    as well, and should no longer produce hot pixels)
  - use ordered arrays in xmp files
  - disable export parallelism for flickr/picasa export
  - don't enter tethering mode when there is no camera attached (this
    made darktable look asif it was hung, even though that wasn't the
    case)
  - bring back the pin for map thumbnails
  - improved tiff support
  - vignetting now has a dithering option (to mitigate occasional
    banding)
  - read nikon subject distance properly
  - assorted freebsd fixes
  - various opencl fixes
  - usermanual updates
  * Support for the following camera's with either preliminarily added
    or updated:
  - canon eos 6d
  - canon powershot s110
  - canon powershot g15
  - canon powershot sx50 hs
  - nikon 1 v2
  - nikon d600
  - nikon coolpix p7700
  - olympus e pl5
  - olympus e pm2
  - olympus xz 2
  - panasonic dmc gh3
  - panasonic dmc lx7
  - pentax k5ii
  - samsung ex2f
  - sony rx1
  - sony nex 6
  - sony slt a99
  - sony nex c3 blackpoint/greenshift fix
  * white balance preset updates:
  - canon eos 550d
  - canon eos 5d mark iii
  - olympus xz 1
  - sony nex c3
  - sony slt a57
  - sony nex 5n
  - panasonic dmc-gh3
* Sun Dec  9 2012 toganm@opensuse.org
- Update to release 1.1.1
  * minor reordering of lighttable mode modules (geotagging, keywords
    and recent collections)
  * cleaned up the default visible plugins when first starting
    darktable
  * in most cases raw files will now show thumbnails in the import
    dialog (thanks to Mattias Eriksson)
  * a curve related crash was fixed (#9906 thanks to James C.
    McPherson)
  * comma seperated tags should work everywhere now (#9006 thanks to
    Tobias Ellinghaus)
  * Ulrich pegelow fixed a huge amount of OpenCL related issues,
    particularly for AMD GPUs
  * we now deal better with hybrid GPU machines (#9074 by Ulrich
  Pegelow)
  * a deadlock in the lens correction module was fixed (#9106 thanks to
    Ulrich Pegelow)
  * we don't delete module presets when cancelling the dialog anymore
    (#9108 thanks to Tobias Ellinghaus)
  * we now have better default memory usage settings (which are set
    upon starting darktable the first time)
  * initial support for SONY NEX 5R
  * preliminary/experimental Canon EOS 6D and Sony RX1 support (future
    changes for these camera's may (for the time being) retroactively
    affect your images)
  * Canon EOS 6D white balance presets (thanks to no_maam_)
  * lots of updates for the usermanual (make sure you download a new
    copy)
- Subpackage the user manual
- enable darktable-viewer by adding sdl to buildrequires
* Tue Nov 27 2012 toganm@opensuse.org
- Update to release 1.1
  * general
    + new camera support, new whitebalance presets, etc., including
    canon eos m support and samsung nx fix
    + similarity matching search for images that look alike.
    + geotagging, complete with map view
    + a lot of bugfixes (mainly thanks to ulrich for his meticulous
    work)
    + facebook exporter (for those who have an account there)
  * ui
    + reworked the much hated `more plugins' widget
    + image grouping:
    + command line interface!
    + tone and base curves got a new user interface to better
    support fine grained workflow
    + visually low-profile controls with finetuning:
    + color correction module got a GUI update since the blog post
    (two circles indicating shadows and highlights instead of the
    quad).
    + live view for tethered shooting!
  * darkroom
    + extensive use of edge-aware filtering techniques to suppress
    noise, halos and ringing all around darktable:
    + conditional blending, and a lot of goodies around it!
    + magenta highlights: high-contrast edges to overexposed areas
    (should get rid of purple highlights on tiny water waves and
    purple fringes around tree leaves for example)
    + much improved sharpness for both export and darkroom view,
    especially for downsampled images and if you use lens
    corrections or rotations/perspective corrections. check the new
    options in the preferences dialog, also one more than mentioned
    in the blog ("demosaicing for zoomed out darkroom mode" to
    trade performance for even more sharpness):
  * color management
    + improved per-screen color management (should reload the
    screen profile automatically)
    + more compatible embedded color profiles (should fix problems
    on windows viewing our images, if that matters) read embedded
    color profiles from jpg
  * opencl
    + most of our modules now can take advantage of your computer's
    gpu power
    + caching for compiled opencl kernels (even in case the driver
    doesn't do it) for faster startup times
  * translations
    + two new translations (both portuguese.. ;) )
    + well translated: cs de es fr it ja nl pl pt_BR pt_PT sv
    + half translated: ca fi gl ro ru sq th zh_CN
- Packaging related :
  * Provide the pdf documentation
  * Remove backported patches as they are part of the package now
    + rsvg_cairo.patch
    + update-curves.patch
  * provide tool to work with database cleanup
    purge_non_existing_images.sh (placed in documentation
    directory)
  * where possible use pkgconfig variables for buildrequires
* Tue Oct  9 2012 toganm@opensuse.org
- Add rsvg_cairo.patch: Fixes Build for factory because of deprecated
  use of  librsvg (from git)
* Sun Aug  5 2012 fcrozat@suse.com
- Add update-curves.patch: add additional basecurves for Olympus
  E-M5 and EOS 5D Mark II/III and Nikon Dxxxx (from git)
* Tue Jul 24 2012 toganm@opensuse.org
- Update to release 1.0.5
  + Update to RawSpeed r438
  + Update to LibRaw 0.14.7
  + White balance presets for Nikon Coolpix P7100 and Panasonic GF3
  + White balance preset updates for Canon EOS 7D, Canon EOS 350D
  + Standard Color Matrices for Canon EOS 650D, Canon EOS 5D Mark
    III, Canon EOS 1D X, Canon PowerShot G1 X, Canon PowerShot SX220,
    Nikon D3200, Nikon D4, Nikon D800, Olympus E-M5, Panasonic GF5,
    Sony SLT-A37/A57, Leica X1/X2, Sony DSC-RX100
  + A few memory leaks were resolved
  + A few generic bugs were resolved
- use -DLENSFUN_INCLUDE_DIR to fix finding lensfun.h
* Thu Jun 14 2012 toganm@opensuse.org
- Disable build for powerppc as darktable requires sse instructions
* Mon Jun  4 2012 toganm@opensuse.org
- Enabled all plugins
* Sun Jun  3 2012 meissner@suse.com
- Update to release 1.0.4
  No upstream changelog, but various improvements, translation updates
  and bugfixes.
* Sat Apr 28 2012 toganm@opensuse.org
- Update to release 1.0.3
  + Usability improvements:
  * Filmstrip centers on selected image
  + Behavioral changes:
  * Improved (hierarchical) tag export for flickr and friends
  + Camera support:
  * Improved Sony NEX-7 support
  * Initial camera support for Nikon D800 and Sony SLT-A57
  * White balance updates for Canon EOS Rebel T3, Olympus E-5 & Nikon
    D800
  + Various:
  * New subtle denoise preset for equalizer
  * Various build fixes
  * Numerous other fixes
* Thu Mar 15 2012 toganm@opensuse.org
- Upgrade to release 1.0
  + new cameras supported
  * Leica M9
  * NX100/NX5/NX10/NX11
  * Panasonic DMC-GX1
  * Pentax K-r
  * Canon Powershot S100
  * Olympus XZ-1
  * Olympus E-P3
  * Sony DSLR A330
  * Sony NEX-5N
  * Canon EOS 1000D
  * Canon EOS 600D
  * Sony Alpha 390
  * Fuji Finepix HS20EXR
  + new and updated translations (we now have chinese!)
  + new image cache
  * faster concurrent access and insertion
  * reduces needed memory
  * more thumbnails stored on disk
  * read embedded jpegs for creating thumbnails (faster folder
    import)
  + increased general speed on sqlite3 (journaled, pagesize
    optimizations)
  + reworked, modular ui
  + keyboard shortcuts support - key accelerators (GSoC)
  + quicktool bar: exposure, presets and styles
  + new color picker
  + web gallery export now with next/prev buttons per image
  + removed gconf: not used anymore, we have our own backend
  + bugfixes
  + there have been issues with memory on 32-bit systems. seems to
    be okay currently, but something to keep in mind. use 64-bits
    if you can
* Tue Feb 28 2012 fcrozat@suse.com
- Add darktable-fix-deprecation.patch to fix glib deprecation.
* Tue Nov  8 2011 toganm@opensuse.org
- Upgrade to release 0.9.3:
  + sse optimizations
  * non-local means
  * graduated density
  * velvia
  * color management
  * equalizer
  * zone system
  + updated translations
  * ru,fr,es,ja,it,sq,pl,nl,de
  + more presets
  * split toning
  * tone curve
  * equalizer
  * color zones
  + lots of bugfixes
  * tiling code (low mem/opencl)
  * gcc 4.6 compat
  + updates
  * libraw 0.14b2
  * rawspeed r379
  as well as more basecurves and color matrices.
- added Mesa-devel to BuildRequires
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Tue Sep 13 2011 toganm@opensuse.org
- Added dbus-1-glib-devel to BuildRequires
* Sat Sep  3 2011 toganm@opensuse.org
- Update to bugfix release 0.9.2:
  + there are no new features, just
  * updated translations
  * tiling for memory hungry operations and as workaround for old
    opencl 1.0 drivers
  * new color matrices and white balance presets
  * a lot of stability issues have been resolved
  * a lot of performance improvements (more sse code, better
    opencl code)
  + Removed 0001-Remove-dependancy-on-git.patch
* Tue Jul 26 2011 toganm@opensuse.org
- Updated to bugfix release 0.9.1
  + new rawspeed, dcraw, libraw
  + fixed various segfaults and deadlocks
  + the pipeline is now more real HDR (no more gamut clipping in
    between)
  + fixed a nasty bug which could cause complete loss of history
    for an image
  + darktable-faster now plays nicely with darktablerc (non-gconf)
  + lots of opencl improvements
  + updated translations
  + second part of our GSoC: customizable keyboard shortcuts!
* Tue Jul  5 2011 toganm@opensuse.org
-Release 0.9:
    + run-time switchable opencl to exploit all the power of your GPU
    whenever you decide to install the driver
    + many new plugins, including a spot removal tool, better denoising
    (on raw pixels and non-local means) and many more
    + blend operations, overlay your plugin only 20 percent if you want
    + spot removal tool
    + low light vision tool
    + non-local-means denoising (relatively fast for nlmeans, but still
    slow)
    + first part of the google summer of code project
    already merged
    + framing plugin (adds postcard borders to match
    given aspect ratio)
    + tonemapping a lot faster now (probably the fastest high-dimensional
    bilateral filter)
    + changed images come with the darktable|changed tag
- removed darktable-08 related patches as they are now in the upstream
- use RPM optflags
* Fri Jun 17 2011 fcrozat@suse.com
- Add darktable-0.8-unused_variables.patch and
  darktable-0.8-clean_up_set_but_unused_variables.patch to fix
  build with gcc 4.6
- Add darktable-0.8-default_generic_optimizations.patch and
  darktable-0.8-binary_package_build.patch: don't optimize build
  for build system.
- Ensure package is build with debuginfo.
* Fri Jun 10 2011 fcrozat@suse.com
- Add libflickcurl-devel BuildRequires to get Flickr upload
  support.
* Thu Mar  3 2011 toganm@opensuse.org
- Fix building for x86_64
* Wed Feb 23 2011 fcrozat@novell.com
- Release 0.8:
  + much faster image loading due to rawspeed, an awesome new
    library by klaus post @rawstudio
  + lots of performance improvements in our caches and pixel
    pipelines (together with the above like 5x--10x)
  + gpu computing using opencl (for graphics boards that support
    it) for a lot of common plugins, to give a huge performance
    boost
  + overhauled collection plugin for more flexible image
    collections
  + metadata editor (set author and copyright information etc)
  + fast demosaicing now done on roi and in floating point
  + HDR bracketing and tone mapping (somewhat experimental)
  + flickr upload
  + lots of new color matrices and white balance presets
  + lots of bugfixes
  + Updated translations
* Mon Dec 13 2010 fcrozat@novell.com
- Release 0.7.1 :
  * some more white balance presets
  * layout fixes for overlong profile names
  * styles now actually work
* Tue Nov 23 2010 bitshuffler@opensuse.org
- Update to 0.7.
* Wed Sep  1 2010 bitshuffler@opensuse.org
- Initial package
